from typing import Any

import proto

from google.ads.googleads.v8.common.types import criteria as criteria

__protobuf__: Any

class CampaignBidModifier(proto.Message):
    resource_name: Any
    campaign: Any
    criterion_id: Any
    bid_modifier: Any
    interaction_type: Any
