from typing import Any

import proto

__protobuf__: Any

class ValueRuleDeviceTypeEnum(proto.Message):
    class ValueRuleDeviceType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        MOBILE: int
        DESKTOP: int
        TABLET: int
