from typing import Any

import proto

__protobuf__: Any

class DisplayUploadProductTypeEnum(proto.Message):
    class DisplayUploadProductType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        HTML5_UPLOAD_AD: int
        DYNAMIC_HTML5_EDUCATION_AD: int
        DYNAMIC_HTML5_FLIGHT_AD: int
        DYNAMIC_HTML5_HOTEL_RENTAL_AD: int
        DYNAMIC_HTML5_JOB_AD: int
        DYNAMIC_HTML5_LOCAL_AD: int
        DYNAMIC_HTML5_REAL_ESTATE_AD: int
        DYNAMIC_HTML5_CUSTOM_AD: int
        DYNAMIC_HTML5_TRAVEL_AD: int
        DYNAMIC_HTML5_HOTEL_AD: int
