from typing import Any

import proto

__protobuf__: Any

class CalloutPlaceholderFieldEnum(proto.Message):
    class CalloutPlaceholderField(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        CALLOUT_TEXT: int
