from typing import Any

import proto

__protobuf__: Any

class LeadFormPostSubmitCallToActionTypeEnum(proto.Message):
    class LeadFormPostSubmitCallToActionType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        VISIT_SITE: int
        DOWNLOAD: int
        LEARN_MORE: int
        SHOP_NOW: int
