from typing import Any

import proto

__protobuf__: Any

class KeywordPlanCampaignKeywordErrorEnum(proto.Message):
    class KeywordPlanCampaignKeywordError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        CAMPAIGN_KEYWORD_IS_POSITIVE: int
