from .base import (
    ParentalStatusViewServiceTransport as ParentalStatusViewServiceTransport,
)
from .grpc import (
    ParentalStatusViewServiceGrpcTransport as ParentalStatusViewServiceGrpcTransport,
)
