from typing import Any

import proto

__protobuf__: Any

class FeedItemTargetDeviceEnum(proto.Message):
    class FeedItemTargetDevice(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        MOBILE: int
