from typing import Any

import proto

from google.ads.googleads.v7.enums.types import (
    conversion_custom_variable_status as conversion_custom_variable_status,
)

__protobuf__: Any

class ConversionCustomVariable(proto.Message):
    resource_name: Any
    id: Any
    name: Any
    tag: Any
    status: Any
    owner_customer: Any
