from typing import Any

import proto

__protobuf__: Any

class AssetErrorEnum(proto.Message):
    class AssetError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        CUSTOMER_NOT_ON_ALLOWLIST_FOR_ASSET_TYPE: int
        DUPLICATE_ASSET: int
        DUPLICATE_ASSET_NAME: int
        ASSET_DATA_IS_MISSING: int
        CANNOT_MODIFY_ASSET_NAME: int
        FIELD_INCOMPATIBLE_WITH_ASSET_TYPE: int
        INVALID_CALL_TO_ACTION_TEXT: int
        LEAD_FORM_INVALID_FIELDS_COMBINATION: int
        LEAD_FORM_MISSING_AGREEMENT: int
        INVALID_ASSET_STATUS: int
        FIELD_CANNOT_BE_MODIFIED_FOR_ASSET_TYPE: int
        SCHEDULES_CANNOT_OVERLAP: int
        PROMOTION_CANNOT_SET_PERCENT_OFF_AND_MONEY_AMOUNT_OFF: int
        PROMOTION_CANNOT_SET_PROMOTION_CODE_AND_ORDERS_OVER_AMOUNT: int
        TOO_MANY_DECIMAL_PLACES_SPECIFIED: int
        DUPLICATE_ASSETS_WITH_DIFFERENT_FIELD_VALUE: int
