from typing import Any

import proto

__protobuf__: Any

class ImagePlaceholderFieldEnum(proto.Message):
    class ImagePlaceholderField(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        ASSET_ID: int
