from typing import Any

import proto

from google.ads.googleads.v8.common.types import tag_snippet as tag_snippet

__protobuf__: Any

class RemarketingAction(proto.Message):
    resource_name: Any
    id: Any
    name: Any
    tag_snippets: Any
