from typing import Any

import proto

__protobuf__: Any

class QueryErrorEnum(proto.Message):
    class QueryError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        QUERY_ERROR: int
        BAD_ENUM_CONSTANT: int
        BAD_ESCAPE_SEQUENCE: int
        BAD_FIELD_NAME: int
        BAD_LIMIT_VALUE: int
        BAD_NUMBER: int
        BAD_OPERATOR: int
        BAD_PARAMETER_NAME: int
        BAD_PARAMETER_VALUE: int
        BAD_RESOURCE_TYPE_IN_FROM_CLAUSE: int
        BAD_SYMBOL: int
        BAD_VALUE: int
        DATE_RANGE_TOO_WIDE: int
        DATE_RANGE_TOO_NARROW: int
        EXPECTED_AND: int
        EXPECTED_BY: int
        EXPECTED_DIMENSION_FIELD_IN_SELECT_CLAUSE: int
        EXPECTED_FILTERS_ON_DATE_RANGE: int
        EXPECTED_FROM: int
        EXPECTED_LIST: int
        EXPECTED_REFERENCED_FIELD_IN_SELECT_CLAUSE: int
        EXPECTED_SELECT: int
        EXPECTED_SINGLE_VALUE: int
        EXPECTED_VALUE_WITH_BETWEEN_OPERATOR: int
        INVALID_DATE_FORMAT: int
        INVALID_STRING_VALUE: int
        INVALID_VALUE_WITH_BETWEEN_OPERATOR: int
        INVALID_VALUE_WITH_DURING_OPERATOR: int
        INVALID_VALUE_WITH_LIKE_OPERATOR: int
        OPERATOR_FIELD_MISMATCH: int
        PROHIBITED_EMPTY_LIST_IN_CONDITION: int
        PROHIBITED_ENUM_CONSTANT: int
        PROHIBITED_FIELD_COMBINATION_IN_SELECT_CLAUSE: int
        PROHIBITED_FIELD_IN_ORDER_BY_CLAUSE: int
        PROHIBITED_FIELD_IN_SELECT_CLAUSE: int
        PROHIBITED_FIELD_IN_WHERE_CLAUSE: int
        PROHIBITED_RESOURCE_TYPE_IN_FROM_CLAUSE: int
        PROHIBITED_RESOURCE_TYPE_IN_SELECT_CLAUSE: int
        PROHIBITED_RESOURCE_TYPE_IN_WHERE_CLAUSE: int
        PROHIBITED_METRIC_IN_SELECT_OR_WHERE_CLAUSE: int
        PROHIBITED_SEGMENT_IN_SELECT_OR_WHERE_CLAUSE: int
        PROHIBITED_SEGMENT_WITH_METRIC_IN_SELECT_OR_WHERE_CLAUSE: int
        LIMIT_VALUE_TOO_LOW: int
        PROHIBITED_NEWLINE_IN_STRING: int
        PROHIBITED_VALUE_COMBINATION_IN_LIST: int
        PROHIBITED_VALUE_COMBINATION_WITH_BETWEEN_OPERATOR: int
        STRING_NOT_TERMINATED: int
        TOO_MANY_SEGMENTS: int
        UNEXPECTED_END_OF_QUERY: int
        UNEXPECTED_FROM_CLAUSE: int
        UNRECOGNIZED_FIELD: int
        UNEXPECTED_INPUT: int
        REQUESTED_METRICS_FOR_MANAGER: int
        FILTER_HAS_TOO_MANY_VALUES: int
