from typing import Any

import proto

__protobuf__: Any

class SettingErrorEnum(proto.Message):
    class SettingError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        SETTING_TYPE_IS_NOT_AVAILABLE: int
        SETTING_TYPE_IS_NOT_COMPATIBLE_WITH_CAMPAIGN: int
        TARGETING_SETTING_CONTAINS_INVALID_CRITERION_TYPE_GROUP: int
        TARGETING_SETTING_DEMOGRAPHIC_CRITERION_TYPE_GROUPS_MUST_BE_SET_TO_TARGET_ALL: int
        TARGETING_SETTING_CANNOT_CHANGE_TARGET_ALL_TO_FALSE_FOR_DEMOGRAPHIC_CRITERION_TYPE_GROUP: int
        DYNAMIC_SEARCH_ADS_SETTING_AT_LEAST_ONE_FEED_ID_MUST_BE_PRESENT: int
        DYNAMIC_SEARCH_ADS_SETTING_CONTAINS_INVALID_DOMAIN_NAME: int
        DYNAMIC_SEARCH_ADS_SETTING_CONTAINS_SUBDOMAIN_NAME: int
        DYNAMIC_SEARCH_ADS_SETTING_CONTAINS_INVALID_LANGUAGE_CODE: int
        TARGET_ALL_IS_NOT_ALLOWED_FOR_PLACEMENT_IN_SEARCH_CAMPAIGN: int
        SETTING_VALUE_NOT_COMPATIBLE_WITH_CAMPAIGN: int
