from typing import Any

import proto

__protobuf__: Any

class PaymentsAccount(proto.Message):
    resource_name: Any
    payments_account_id: Any
    name: Any
    currency_code: Any
    payments_profile_id: Any
    secondary_payments_profile_id: Any
    paying_manager_customer: Any
