from typing import Any

import proto

__protobuf__: Any

class ProductCustomAttributeIndexEnum(proto.Message):
    class ProductCustomAttributeIndex(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        INDEX0: int
        INDEX1: int
        INDEX2: int
        INDEX3: int
        INDEX4: int
