from typing import Any

import proto

__protobuf__: Any

class ProximityRadiusUnitsEnum(proto.Message):
    class ProximityRadiusUnits(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        MILES: int
        KILOMETERS: int
