from .base import (
    ProductBiddingCategoryConstantServiceTransport as ProductBiddingCategoryConstantServiceTransport,
)
from .grpc import (
    ProductBiddingCategoryConstantServiceGrpcTransport as ProductBiddingCategoryConstantServiceGrpcTransport,
)
