from typing import Any

import proto

__protobuf__: Any

class TrackingCodePageFormatEnum(proto.Message):
    class TrackingCodePageFormat(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        HTML: int
        AMP: int
