from typing import Any

import proto

__protobuf__: Any

class DsaPageFeedCriterionFieldEnum(proto.Message):
    class DsaPageFeedCriterionField(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        PAGE_URL: int
        LABEL: int
