from typing import Any

import proto

__protobuf__: Any

class FrequencyCapTimeUnitEnum(proto.Message):
    class FrequencyCapTimeUnit(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        DAY: int
        WEEK: int
        MONTH: int
