from typing import Any

import proto

__protobuf__: Any

class AccountLinkErrorEnum(proto.Message):
    class AccountLinkError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        INVALID_STATUS: int
