from typing import Any

import proto

from google.ads.googleads.v8.common.types import (
    criterion_category_availability as criterion_category_availability,
)

__protobuf__: Any

class DetailedDemographic(proto.Message):
    resource_name: Any
    id: Any
    name: Any
    parent: Any
    launched_to_all: Any
    availabilities: Any
