from typing import Any

import proto

__protobuf__: Any

class AdCustomizerPlaceholderFieldEnum(proto.Message):
    class AdCustomizerPlaceholderField(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        INTEGER: int
        PRICE: int
        DATE: int
        STRING: int
