from typing import Any

import proto

from google.ads.googleads.v8.enums.types import label_status as label_status

__protobuf__: Any

class Label(proto.Message):
    resource_name: Any
    id: Any
    name: Any
    status: Any
    text_label: Any
