from .base import (
    GroupPlacementViewServiceTransport as GroupPlacementViewServiceTransport,
)
from .grpc import (
    GroupPlacementViewServiceGrpcTransport as GroupPlacementViewServiceGrpcTransport,
)
