from typing import Any

import proto

__protobuf__: Any

class LeadFormCallToActionTypeEnum(proto.Message):
    class LeadFormCallToActionType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        LEARN_MORE: int
        GET_QUOTE: int
        APPLY_NOW: int
        SIGN_UP: int
        CONTACT_US: int
        SUBSCRIBE: int
        DOWNLOAD: int
        BOOK_NOW: int
        GET_OFFER: int
        REGISTER: int
        GET_INFO: int
        REQUEST_DEMO: int
        JOIN_NOW: int
        GET_STARTED: int
