from typing import Any

import proto

__protobuf__: Any

class KeywordPlanKeywordAnnotationEnum(proto.Message):
    class KeywordPlanKeywordAnnotation(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        KEYWORD_CONCEPT: int
