from .base import (
    ManagedPlacementViewServiceTransport as ManagedPlacementViewServiceTransport,
)
from .grpc import (
    ManagedPlacementViewServiceGrpcTransport as ManagedPlacementViewServiceGrpcTransport,
)
