from typing import Any

import proto

__protobuf__: Any

class ReachPlanAgeRangeEnum(proto.Message):
    class ReachPlanAgeRange(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        AGE_RANGE_18_24: int
        AGE_RANGE_18_34: int
        AGE_RANGE_18_44: int
        AGE_RANGE_18_49: int
        AGE_RANGE_18_54: int
        AGE_RANGE_18_64: int
        AGE_RANGE_18_65_UP: int
        AGE_RANGE_21_34: int
        AGE_RANGE_25_34: int
        AGE_RANGE_25_44: int
        AGE_RANGE_25_49: int
        AGE_RANGE_25_54: int
        AGE_RANGE_25_64: int
        AGE_RANGE_25_65_UP: int
        AGE_RANGE_35_44: int
        AGE_RANGE_35_49: int
        AGE_RANGE_35_54: int
        AGE_RANGE_35_64: int
        AGE_RANGE_35_65_UP: int
        AGE_RANGE_45_54: int
        AGE_RANGE_45_64: int
        AGE_RANGE_45_65_UP: int
        AGE_RANGE_50_65_UP: int
        AGE_RANGE_55_64: int
        AGE_RANGE_55_65_UP: int
        AGE_RANGE_65_UP: int
