from typing import Any

import proto

__protobuf__: Any

class DynamicSearchAdsSearchTermView(proto.Message):
    resource_name: Any
    search_term: Any
    headline: Any
    landing_page: Any
    page_url: Any
    has_negative_keyword: Any
    has_matching_keyword: Any
    has_negative_url: Any
