from typing import Any

import proto

__protobuf__: Any

class KeywordPlanNetworkEnum(proto.Message):
    class KeywordPlanNetwork(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        GOOGLE_SEARCH: int
        GOOGLE_SEARCH_AND_PARTNERS: int
