from typing import Any

import proto

__protobuf__: Any

class ReachPlanNetworkEnum(proto.Message):
    class ReachPlanNetwork(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        YOUTUBE: int
        GOOGLE_VIDEO_PARTNERS: int
        YOUTUBE_AND_GOOGLE_VIDEO_PARTNERS: int
