from typing import Any

import proto

__protobuf__: Any

class FeedItemValidationErrorEnum(proto.Message):
    class FeedItemValidationError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        STRING_TOO_SHORT: int
        STRING_TOO_LONG: int
        VALUE_NOT_SPECIFIED: int
        INVALID_DOMESTIC_PHONE_NUMBER_FORMAT: int
        INVALID_PHONE_NUMBER: int
        PHONE_NUMBER_NOT_SUPPORTED_FOR_COUNTRY: int
        PREMIUM_RATE_NUMBER_NOT_ALLOWED: int
        DISALLOWED_NUMBER_TYPE: int
        VALUE_OUT_OF_RANGE: int
        CALLTRACKING_NOT_SUPPORTED_FOR_COUNTRY: int
        CUSTOMER_NOT_IN_ALLOWLIST_FOR_CALLTRACKING: int
        INVALID_COUNTRY_CODE: int
        INVALID_APP_ID: int
        MISSING_ATTRIBUTES_FOR_FIELDS: int
        INVALID_TYPE_ID: int
        INVALID_EMAIL_ADDRESS: int
        INVALID_HTTPS_URL: int
        MISSING_DELIVERY_ADDRESS: int
        START_DATE_AFTER_END_DATE: int
        MISSING_FEED_ITEM_START_TIME: int
        MISSING_FEED_ITEM_END_TIME: int
        MISSING_FEED_ITEM_ID: int
        VANITY_PHONE_NUMBER_NOT_ALLOWED: int
        INVALID_REVIEW_EXTENSION_SNIPPET: int
        INVALID_NUMBER_FORMAT: int
        INVALID_DATE_FORMAT: int
        INVALID_PRICE_FORMAT: int
        UNKNOWN_PLACEHOLDER_FIELD: int
        MISSING_ENHANCED_SITELINK_DESCRIPTION_LINE: int
        REVIEW_EXTENSION_SOURCE_INELIGIBLE: int
        HYPHENS_IN_REVIEW_EXTENSION_SNIPPET: int
        DOUBLE_QUOTES_IN_REVIEW_EXTENSION_SNIPPET: int
        QUOTES_IN_REVIEW_EXTENSION_SNIPPET: int
        INVALID_FORM_ENCODED_PARAMS: int
        INVALID_URL_PARAMETER_NAME: int
        NO_GEOCODING_RESULT: int
        SOURCE_NAME_IN_REVIEW_EXTENSION_TEXT: int
        CARRIER_SPECIFIC_SHORT_NUMBER_NOT_ALLOWED: int
        INVALID_PLACEHOLDER_FIELD_ID: int
        INVALID_URL_TAG: int
        LIST_TOO_LONG: int
        INVALID_ATTRIBUTES_COMBINATION: int
        DUPLICATE_VALUES: int
        INVALID_CALL_CONVERSION_ACTION_ID: int
        CANNOT_SET_WITHOUT_FINAL_URLS: int
        APP_ID_DOESNT_EXIST_IN_APP_STORE: int
        INVALID_FINAL_URL: int
        INVALID_TRACKING_URL: int
        INVALID_FINAL_URL_FOR_APP_DOWNLOAD_URL: int
        LIST_TOO_SHORT: int
        INVALID_USER_ACTION: int
        INVALID_TYPE_NAME: int
        INVALID_EVENT_CHANGE_STATUS: int
        INVALID_SNIPPETS_HEADER: int
        INVALID_ANDROID_APP_LINK: int
        NUMBER_TYPE_WITH_CALLTRACKING_NOT_SUPPORTED_FOR_COUNTRY: int
        RESERVED_KEYWORD_OTHER: int
        DUPLICATE_OPTION_LABELS: int
        DUPLICATE_OPTION_PREFILLS: int
        UNEQUAL_LIST_LENGTHS: int
        INCONSISTENT_CURRENCY_CODES: int
        PRICE_EXTENSION_HAS_DUPLICATED_HEADERS: int
        ITEM_HAS_DUPLICATED_HEADER_AND_DESCRIPTION: int
        PRICE_EXTENSION_HAS_TOO_FEW_ITEMS: int
        UNSUPPORTED_VALUE: int
        INVALID_FINAL_MOBILE_URL: int
        INVALID_KEYWORDLESS_AD_RULE_LABEL: int
        VALUE_TRACK_PARAMETER_NOT_SUPPORTED: int
        UNSUPPORTED_VALUE_IN_SELECTED_LANGUAGE: int
        INVALID_IOS_APP_LINK: int
        MISSING_IOS_APP_LINK_OR_IOS_APP_STORE_ID: int
        PROMOTION_INVALID_TIME: int
        PROMOTION_CANNOT_SET_PERCENT_OFF_AND_MONEY_AMOUNT_OFF: int
        PROMOTION_CANNOT_SET_PROMOTION_CODE_AND_ORDERS_OVER_AMOUNT: int
        TOO_MANY_DECIMAL_PLACES_SPECIFIED: int
        AD_CUSTOMIZERS_NOT_ALLOWED: int
        INVALID_LANGUAGE_CODE: int
        UNSUPPORTED_LANGUAGE: int
        IF_FUNCTION_NOT_ALLOWED: int
        INVALID_FINAL_URL_SUFFIX: int
        INVALID_TAG_IN_FINAL_URL_SUFFIX: int
        INVALID_FINAL_URL_SUFFIX_FORMAT: int
        CUSTOMER_CONSENT_FOR_CALL_RECORDING_REQUIRED: int
        ONLY_ONE_DELIVERY_OPTION_IS_ALLOWED: int
        NO_DELIVERY_OPTION_IS_SET: int
        INVALID_CONVERSION_REPORTING_STATE: int
        IMAGE_SIZE_WRONG: int
        EMAIL_DELIVERY_NOT_AVAILABLE_IN_COUNTRY: int
        AUTO_REPLY_NOT_AVAILABLE_IN_COUNTRY: int
        INVALID_LATITUDE_VALUE: int
        INVALID_LONGITUDE_VALUE: int
        TOO_MANY_LABELS: int
        INVALID_IMAGE_URL: int
        MISSING_LATITUDE_VALUE: int
        MISSING_LONGITUDE_VALUE: int
        ADDRESS_NOT_FOUND: int
        ADDRESS_NOT_TARGETABLE: int
        INVALID_ASSET_ID: int
        INCOMPATIBLE_ASSET_TYPE: int
        IMAGE_ERROR_UNEXPECTED_SIZE: int
        IMAGE_ERROR_ASPECT_RATIO_NOT_ALLOWED: int
        IMAGE_ERROR_FILE_TOO_LARGE: int
        IMAGE_ERROR_FORMAT_NOT_ALLOWED: int
        IMAGE_ERROR_CONSTRAINTS_VIOLATED: int
        IMAGE_ERROR_SERVER_ERROR: int
