from typing import Any

import proto

__protobuf__: Any

class SpendingLimitTypeEnum(proto.Message):
    class SpendingLimitType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        INFINITE: int
