from typing import Any

import proto

__protobuf__: Any

class ConversionOrAdjustmentLagBucketEnum(proto.Message):
    class ConversionOrAdjustmentLagBucket(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        CONVERSION_LESS_THAN_ONE_DAY: int
        CONVERSION_ONE_TO_TWO_DAYS: int
        CONVERSION_TWO_TO_THREE_DAYS: int
        CONVERSION_THREE_TO_FOUR_DAYS: int
        CONVERSION_FOUR_TO_FIVE_DAYS: int
        CONVERSION_FIVE_TO_SIX_DAYS: int
        CONVERSION_SIX_TO_SEVEN_DAYS: int
        CONVERSION_SEVEN_TO_EIGHT_DAYS: int
        CONVERSION_EIGHT_TO_NINE_DAYS: int
        CONVERSION_NINE_TO_TEN_DAYS: int
        CONVERSION_TEN_TO_ELEVEN_DAYS: int
        CONVERSION_ELEVEN_TO_TWELVE_DAYS: int
        CONVERSION_TWELVE_TO_THIRTEEN_DAYS: int
        CONVERSION_THIRTEEN_TO_FOURTEEN_DAYS: int
        CONVERSION_FOURTEEN_TO_TWENTY_ONE_DAYS: int
        CONVERSION_TWENTY_ONE_TO_THIRTY_DAYS: int
        CONVERSION_THIRTY_TO_FORTY_FIVE_DAYS: int
        CONVERSION_FORTY_FIVE_TO_SIXTY_DAYS: int
        CONVERSION_SIXTY_TO_NINETY_DAYS: int
        ADJUSTMENT_LESS_THAN_ONE_DAY: int
        ADJUSTMENT_ONE_TO_TWO_DAYS: int
        ADJUSTMENT_TWO_TO_THREE_DAYS: int
        ADJUSTMENT_THREE_TO_FOUR_DAYS: int
        ADJUSTMENT_FOUR_TO_FIVE_DAYS: int
        ADJUSTMENT_FIVE_TO_SIX_DAYS: int
        ADJUSTMENT_SIX_TO_SEVEN_DAYS: int
        ADJUSTMENT_SEVEN_TO_EIGHT_DAYS: int
        ADJUSTMENT_EIGHT_TO_NINE_DAYS: int
        ADJUSTMENT_NINE_TO_TEN_DAYS: int
        ADJUSTMENT_TEN_TO_ELEVEN_DAYS: int
        ADJUSTMENT_ELEVEN_TO_TWELVE_DAYS: int
        ADJUSTMENT_TWELVE_TO_THIRTEEN_DAYS: int
        ADJUSTMENT_THIRTEEN_TO_FOURTEEN_DAYS: int
        ADJUSTMENT_FOURTEEN_TO_TWENTY_ONE_DAYS: int
        ADJUSTMENT_TWENTY_ONE_TO_THIRTY_DAYS: int
        ADJUSTMENT_THIRTY_TO_FORTY_FIVE_DAYS: int
        ADJUSTMENT_FORTY_FIVE_TO_SIXTY_DAYS: int
        ADJUSTMENT_SIXTY_TO_NINETY_DAYS: int
        ADJUSTMENT_NINETY_TO_ONE_HUNDRED_AND_FORTY_FIVE_DAYS: int
        CONVERSION_UNKNOWN: int
        ADJUSTMENT_UNKNOWN: int
