from typing import Any

import proto

__protobuf__: Any

class PolicyTopicEvidenceDestinationNotWorkingDeviceEnum(proto.Message):
    class PolicyTopicEvidenceDestinationNotWorkingDevice(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        DESKTOP: int
        ANDROID: int
        IOS: int
