from typing import Any

import proto

__protobuf__: Any

class SimulationModificationMethodEnum(proto.Message):
    class SimulationModificationMethod(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        UNIFORM: int
        DEFAULT: int
        SCALING: int
