from typing import Any

import proto

__protobuf__: Any

class ResourceLimitTypeEnum(proto.Message):
    class ResourceLimitType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        CAMPAIGNS_PER_CUSTOMER: int
        BASE_CAMPAIGNS_PER_CUSTOMER: int
        EXPERIMENT_CAMPAIGNS_PER_CUSTOMER: int
        HOTEL_CAMPAIGNS_PER_CUSTOMER: int
        SMART_SHOPPING_CAMPAIGNS_PER_CUSTOMER: int
        AD_GROUPS_PER_CAMPAIGN: int
        AD_GROUPS_PER_SHOPPING_CAMPAIGN: int
        AD_GROUPS_PER_HOTEL_CAMPAIGN: int
        REPORTING_AD_GROUPS_PER_LOCAL_CAMPAIGN: int
        REPORTING_AD_GROUPS_PER_APP_CAMPAIGN: int
        MANAGED_AD_GROUPS_PER_SMART_CAMPAIGN: int
        AD_GROUP_CRITERIA_PER_CUSTOMER: int
        BASE_AD_GROUP_CRITERIA_PER_CUSTOMER: int
        EXPERIMENT_AD_GROUP_CRITERIA_PER_CUSTOMER: int
        AD_GROUP_CRITERIA_PER_CAMPAIGN: int
        CAMPAIGN_CRITERIA_PER_CUSTOMER: int
        BASE_CAMPAIGN_CRITERIA_PER_CUSTOMER: int
        EXPERIMENT_CAMPAIGN_CRITERIA_PER_CUSTOMER: int
        WEBPAGE_CRITERIA_PER_CUSTOMER: int
        BASE_WEBPAGE_CRITERIA_PER_CUSTOMER: int
        EXPERIMENT_WEBPAGE_CRITERIA_PER_CUSTOMER: int
        COMBINED_AUDIENCE_CRITERIA_PER_AD_GROUP: int
        CUSTOMER_NEGATIVE_PLACEMENT_CRITERIA_PER_CUSTOMER: int
        CUSTOMER_NEGATIVE_YOUTUBE_CHANNEL_CRITERIA_PER_CUSTOMER: int
        CRITERIA_PER_AD_GROUP: int
        LISTING_GROUPS_PER_AD_GROUP: int
        EXPLICITLY_SHARED_BUDGETS_PER_CUSTOMER: int
        IMPLICITLY_SHARED_BUDGETS_PER_CUSTOMER: int
        COMBINED_AUDIENCE_CRITERIA_PER_CAMPAIGN: int
        NEGATIVE_KEYWORDS_PER_CAMPAIGN: int
        NEGATIVE_PLACEMENTS_PER_CAMPAIGN: int
        GEO_TARGETS_PER_CAMPAIGN: int
        NEGATIVE_IP_BLOCKS_PER_CAMPAIGN: int
        PROXIMITIES_PER_CAMPAIGN: int
        LISTING_SCOPES_PER_SHOPPING_CAMPAIGN: int
        LISTING_SCOPES_PER_NON_SHOPPING_CAMPAIGN: int
        NEGATIVE_KEYWORDS_PER_SHARED_SET: int
        NEGATIVE_PLACEMENTS_PER_SHARED_SET: int
        SHARED_SETS_PER_CUSTOMER_FOR_TYPE_DEFAULT: int
        SHARED_SETS_PER_CUSTOMER_FOR_NEGATIVE_PLACEMENT_LIST_LOWER: int
        HOTEL_ADVANCE_BOOKING_WINDOW_BID_MODIFIERS_PER_AD_GROUP: int
        BIDDING_STRATEGIES_PER_CUSTOMER: int
        BASIC_USER_LISTS_PER_CUSTOMER: int
        LOGICAL_USER_LISTS_PER_CUSTOMER: int
        BASE_AD_GROUP_ADS_PER_CUSTOMER: int
        EXPERIMENT_AD_GROUP_ADS_PER_CUSTOMER: int
        AD_GROUP_ADS_PER_CAMPAIGN: int
        TEXT_AND_OTHER_ADS_PER_AD_GROUP: int
        IMAGE_ADS_PER_AD_GROUP: int
        SHOPPING_SMART_ADS_PER_AD_GROUP: int
        RESPONSIVE_SEARCH_ADS_PER_AD_GROUP: int
        APP_ADS_PER_AD_GROUP: int
        APP_ENGAGEMENT_ADS_PER_AD_GROUP: int
        LOCAL_ADS_PER_AD_GROUP: int
        VIDEO_ADS_PER_AD_GROUP: int
        LEAD_FORM_ASSET_LINKS_PER_CAMPAIGN: int
        VERSIONS_PER_AD: int
        USER_FEEDS_PER_CUSTOMER: int
        SYSTEM_FEEDS_PER_CUSTOMER: int
        FEED_ATTRIBUTES_PER_FEED: int
        FEED_ITEMS_PER_CUSTOMER: int
        CAMPAIGN_FEEDS_PER_CUSTOMER: int
        BASE_CAMPAIGN_FEEDS_PER_CUSTOMER: int
        EXPERIMENT_CAMPAIGN_FEEDS_PER_CUSTOMER: int
        AD_GROUP_FEEDS_PER_CUSTOMER: int
        BASE_AD_GROUP_FEEDS_PER_CUSTOMER: int
        EXPERIMENT_AD_GROUP_FEEDS_PER_CUSTOMER: int
        AD_GROUP_FEEDS_PER_CAMPAIGN: int
        FEED_ITEM_SETS_PER_CUSTOMER: int
        FEED_ITEMS_PER_FEED_ITEM_SET: int
        CAMPAIGN_EXPERIMENTS_PER_CUSTOMER: int
        EXPERIMENT_ARMS_PER_VIDEO_EXPERIMENT: int
        OWNED_LABELS_PER_CUSTOMER: int
        LABELS_PER_CAMPAIGN: int
        LABELS_PER_AD_GROUP: int
        LABELS_PER_AD_GROUP_AD: int
        LABELS_PER_AD_GROUP_CRITERION: int
        TARGET_CUSTOMERS_PER_LABEL: int
        KEYWORD_PLANS_PER_USER_PER_CUSTOMER: int
        KEYWORD_PLAN_AD_GROUP_KEYWORDS_PER_KEYWORD_PLAN: int
        KEYWORD_PLAN_AD_GROUPS_PER_KEYWORD_PLAN: int
        KEYWORD_PLAN_NEGATIVE_KEYWORDS_PER_KEYWORD_PLAN: int
        KEYWORD_PLAN_CAMPAIGNS_PER_KEYWORD_PLAN: int
        CONVERSION_ACTIONS_PER_CUSTOMER: int
        BATCH_JOB_OPERATIONS_PER_JOB: int
        BATCH_JOBS_PER_CUSTOMER: int
        HOTEL_CHECK_IN_DATE_RANGE_BID_MODIFIERS_PER_AD_GROUP: int
