from typing import Any

import proto

__protobuf__: Any

class LocationGroupRadiusUnitsEnum(proto.Message):
    class LocationGroupRadiusUnits(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        METERS: int
        MILES: int
        MILLI_MILES: int
