from typing import Any

import proto

__protobuf__: Any

class KeywordPlanConceptGroupTypeEnum(proto.Message):
    class KeywordPlanConceptGroupType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        BRAND: int
        OTHER_BRANDS: int
        NON_BRAND: int
