from typing import Any

import proto

__protobuf__: Any

class CampaignBudgetErrorEnum(proto.Message):
    class CampaignBudgetError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        CAMPAIGN_BUDGET_CANNOT_BE_SHARED: int
        CAMPAIGN_BUDGET_REMOVED: int
        CAMPAIGN_BUDGET_IN_USE: int
        CAMPAIGN_BUDGET_PERIOD_NOT_AVAILABLE: int
        CANNOT_MODIFY_FIELD_OF_IMPLICITLY_SHARED_CAMPAIGN_BUDGET: int
        CANNOT_UPDATE_CAMPAIGN_BUDGET_TO_IMPLICITLY_SHARED: int
        CANNOT_UPDATE_CAMPAIGN_BUDGET_TO_EXPLICITLY_SHARED_WITHOUT_NAME: int
        CANNOT_UPDATE_CAMPAIGN_BUDGET_TO_EXPLICITLY_SHARED: int
        CANNOT_USE_IMPLICITLY_SHARED_CAMPAIGN_BUDGET_WITH_MULTIPLE_CAMPAIGNS: int
        DUPLICATE_NAME: int
        MONEY_AMOUNT_IN_WRONG_CURRENCY: int
        MONEY_AMOUNT_LESS_THAN_CURRENCY_MINIMUM_CPC: int
        MONEY_AMOUNT_TOO_LARGE: int
        NEGATIVE_MONEY_AMOUNT: int
        NON_MULTIPLE_OF_MINIMUM_CURRENCY_UNIT: int
        TOTAL_BUDGET_AMOUNT_MUST_BE_UNSET_FOR_BUDGET_PERIOD_DAILY: int
