from typing import Any

import proto

from google.ads.googleads.v8.enums.types import (
    app_url_operating_system_type as app_url_operating_system_type,
)

__protobuf__: Any

class FinalAppUrl(proto.Message):
    os_type: Any
    url: Any
