from typing import Any

import proto

__protobuf__: Any

class OperatingSystemVersionOperatorTypeEnum(proto.Message):
    class OperatingSystemVersionOperatorType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        EQUALS_TO: int
        GREATER_THAN_EQUALS_TO: int
