from typing import Any

import proto

__protobuf__: Any

class MinuteOfHourEnum(proto.Message):
    class MinuteOfHour(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        ZERO: int
        FIFTEEN: int
        THIRTY: int
        FORTY_FIVE: int
