from typing import Any

import proto

__protobuf__: Any

class KeywordPlanAdGroupErrorEnum(proto.Message):
    class KeywordPlanAdGroupError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        INVALID_NAME: int
        DUPLICATE_NAME: int
