from typing import Any

import proto

__protobuf__: Any

class FeedMappingErrorEnum(proto.Message):
    class FeedMappingError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        INVALID_PLACEHOLDER_FIELD: int
        INVALID_CRITERION_FIELD: int
        INVALID_PLACEHOLDER_TYPE: int
        INVALID_CRITERION_TYPE: int
        NO_ATTRIBUTE_FIELD_MAPPINGS: int
        FEED_ATTRIBUTE_TYPE_MISMATCH: int
        CANNOT_OPERATE_ON_MAPPINGS_FOR_SYSTEM_GENERATED_FEED: int
        MULTIPLE_MAPPINGS_FOR_PLACEHOLDER_TYPE: int
        MULTIPLE_MAPPINGS_FOR_CRITERION_TYPE: int
        MULTIPLE_MAPPINGS_FOR_PLACEHOLDER_FIELD: int
        MULTIPLE_MAPPINGS_FOR_CRITERION_FIELD: int
        UNEXPECTED_ATTRIBUTE_FIELD_MAPPINGS: int
        LOCATION_PLACEHOLDER_ONLY_FOR_PLACES_FEEDS: int
        CANNOT_MODIFY_MAPPINGS_FOR_TYPED_FEED: int
        INVALID_PLACEHOLDER_TYPE_FOR_NON_SYSTEM_GENERATED_FEED: int
        INVALID_PLACEHOLDER_TYPE_FOR_SYSTEM_GENERATED_FEED_TYPE: int
        ATTRIBUTE_FIELD_MAPPING_MISSING_FIELD: int
