from typing import Any

import proto

__protobuf__: Any

class PromotionExtensionDiscountModifierEnum(proto.Message):
    class PromotionExtensionDiscountModifier(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        UP_TO: int
