from typing import Any

import proto

__protobuf__: Any

class ClickTypeEnum(proto.Message):
    class ClickType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        APP_DEEPLINK: int
        BREADCRUMBS: int
        BROADBAND_PLAN: int
        CALL_TRACKING: int
        CALLS: int
        CLICK_ON_ENGAGEMENT_AD: int
        GET_DIRECTIONS: int
        LOCATION_EXPANSION: int
        LOCATION_FORMAT_CALL: int
        LOCATION_FORMAT_DIRECTIONS: int
        LOCATION_FORMAT_IMAGE: int
        LOCATION_FORMAT_LANDING_PAGE: int
        LOCATION_FORMAT_MAP: int
        LOCATION_FORMAT_STORE_INFO: int
        LOCATION_FORMAT_TEXT: int
        MOBILE_CALL_TRACKING: int
        OFFER_PRINTS: int
        OTHER: int
        PRODUCT_EXTENSION_CLICKS: int
        PRODUCT_LISTING_AD_CLICKS: int
        SITELINKS: int
        STORE_LOCATOR: int
        URL_CLICKS: int
        VIDEO_APP_STORE_CLICKS: int
        VIDEO_CALL_TO_ACTION_CLICKS: int
        VIDEO_CARD_ACTION_HEADLINE_CLICKS: int
        VIDEO_END_CAP_CLICKS: int
        VIDEO_WEBSITE_CLICKS: int
        VISUAL_SITELINKS: int
        WIRELESS_PLAN: int
        PRODUCT_LISTING_AD_LOCAL: int
        PRODUCT_LISTING_AD_MULTICHANNEL_LOCAL: int
        PRODUCT_LISTING_AD_MULTICHANNEL_ONLINE: int
        PRODUCT_LISTING_ADS_COUPON: int
        PRODUCT_LISTING_AD_TRANSACTABLE: int
        PRODUCT_AD_APP_DEEPLINK: int
        SHOWCASE_AD_CATEGORY_LINK: int
        SHOWCASE_AD_LOCAL_STOREFRONT_LINK: int
        SHOWCASE_AD_ONLINE_PRODUCT_LINK: int
        SHOWCASE_AD_LOCAL_PRODUCT_LINK: int
        PROMOTION_EXTENSION: int
        SWIPEABLE_GALLERY_AD_HEADLINE: int
        SWIPEABLE_GALLERY_AD_SWIPES: int
        SWIPEABLE_GALLERY_AD_SEE_MORE: int
        SWIPEABLE_GALLERY_AD_SITELINK_ONE: int
        SWIPEABLE_GALLERY_AD_SITELINK_TWO: int
        SWIPEABLE_GALLERY_AD_SITELINK_THREE: int
        SWIPEABLE_GALLERY_AD_SITELINK_FOUR: int
        SWIPEABLE_GALLERY_AD_SITELINK_FIVE: int
        HOTEL_PRICE: int
        PRICE_EXTENSION: int
        HOTEL_BOOK_ON_GOOGLE_ROOM_SELECTION: int
        SHOPPING_COMPARISON_LISTING: int
