from typing import Any

import proto

__protobuf__: Any

class AdGroupAdRotationModeEnum(proto.Message):
    class AdGroupAdRotationMode(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        OPTIMIZE: int
        ROTATE_FOREVER: int
