from typing import Any

import proto

__protobuf__: Any

class AppCampaignAppStoreEnum(proto.Message):
    class AppCampaignAppStore(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        APPLE_APP_STORE: int
        GOOGLE_APP_STORE: int
