from typing import Any

import proto

__protobuf__: Any

class FeedItemQualityDisapprovalReasonEnum(proto.Message):
    class FeedItemQualityDisapprovalReason(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        PRICE_TABLE_REPETITIVE_HEADERS: int
        PRICE_TABLE_REPETITIVE_DESCRIPTION: int
        PRICE_TABLE_INCONSISTENT_ROWS: int
        PRICE_DESCRIPTION_HAS_PRICE_QUALIFIERS: int
        PRICE_UNSUPPORTED_LANGUAGE: int
        PRICE_TABLE_ROW_HEADER_TABLE_TYPE_MISMATCH: int
        PRICE_TABLE_ROW_HEADER_HAS_PROMOTIONAL_TEXT: int
        PRICE_TABLE_ROW_DESCRIPTION_NOT_RELEVANT: int
        PRICE_TABLE_ROW_DESCRIPTION_HAS_PROMOTIONAL_TEXT: int
        PRICE_TABLE_ROW_HEADER_DESCRIPTION_REPETITIVE: int
        PRICE_TABLE_ROW_UNRATEABLE: int
        PRICE_TABLE_ROW_PRICE_INVALID: int
        PRICE_TABLE_ROW_URL_INVALID: int
        PRICE_HEADER_OR_DESCRIPTION_HAS_PRICE: int
        STRUCTURED_SNIPPETS_HEADER_POLICY_VIOLATED: int
        STRUCTURED_SNIPPETS_REPEATED_VALUES: int
        STRUCTURED_SNIPPETS_EDITORIAL_GUIDELINES: int
        STRUCTURED_SNIPPETS_HAS_PROMOTIONAL_TEXT: int
