from typing import Any

import proto

__protobuf__: Any

class CustomInterestMemberTypeEnum(proto.Message):
    class CustomInterestMemberType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        KEYWORD: int
        URL: int
