from typing import Any

import proto

__protobuf__: Any

class VanityPharmaDisplayUrlModeEnum(proto.Message):
    class VanityPharmaDisplayUrlMode(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        MANUFACTURER_WEBSITE_URL: int
        WEBSITE_DESCRIPTION: int
