from typing import Any

import proto

__protobuf__: Any

class PromotionExtensionOccasionEnum(proto.Message):
    class PromotionExtensionOccasion(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        NEW_YEARS: int
        CHINESE_NEW_YEAR: int
        VALENTINES_DAY: int
        EASTER: int
        MOTHERS_DAY: int
        FATHERS_DAY: int
        LABOR_DAY: int
        BACK_TO_SCHOOL: int
        HALLOWEEN: int
        BLACK_FRIDAY: int
        CYBER_MONDAY: int
        CHRISTMAS: int
        BOXING_DAY: int
        INDEPENDENCE_DAY: int
        NATIONAL_DAY: int
        END_OF_SEASON: int
        WINTER_SALE: int
        SUMMER_SALE: int
        FALL_SALE: int
        SPRING_SALE: int
        RAMADAN: int
        EID_AL_FITR: int
        EID_AL_ADHA: int
        SINGLES_DAY: int
        WOMENS_DAY: int
        HOLI: int
        PARENTS_DAY: int
        ST_NICHOLAS_DAY: int
        CARNIVAL: int
        EPIPHANY: int
        ROSH_HASHANAH: int
        PASSOVER: int
        HANUKKAH: int
        DIWALI: int
        NAVRATRI: int
        SONGKRAN: int
        YEAR_END_GIFT: int
