from typing import Any

import proto

__protobuf__: Any

class GetThirdPartyAppAnalyticsLinkRequest(proto.Message):
    resource_name: Any

class RegenerateShareableLinkIdRequest(proto.Message):
    resource_name: Any

class RegenerateShareableLinkIdResponse(proto.Message): ...
