from typing import Any

import proto

__protobuf__: Any

class KeywordPlanAggregateMetricTypeEnum(proto.Message):
    class KeywordPlanAggregateMetricType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        DEVICE: int
