from typing import Any

import proto

__protobuf__: Any

class CriterionErrorEnum(proto.Message):
    class CriterionError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        CONCRETE_TYPE_REQUIRED: int
        INVALID_EXCLUDED_CATEGORY: int
        INVALID_KEYWORD_TEXT: int
        KEYWORD_TEXT_TOO_LONG: int
        KEYWORD_HAS_TOO_MANY_WORDS: int
        KEYWORD_HAS_INVALID_CHARS: int
        INVALID_PLACEMENT_URL: int
        INVALID_USER_LIST: int
        INVALID_USER_INTEREST: int
        INVALID_FORMAT_FOR_PLACEMENT_URL: int
        PLACEMENT_URL_IS_TOO_LONG: int
        PLACEMENT_URL_HAS_ILLEGAL_CHAR: int
        PLACEMENT_URL_HAS_MULTIPLE_SITES_IN_LINE: int
        PLACEMENT_IS_NOT_AVAILABLE_FOR_TARGETING_OR_EXCLUSION: int
        INVALID_TOPIC_PATH: int
        INVALID_YOUTUBE_CHANNEL_ID: int
        INVALID_YOUTUBE_VIDEO_ID: int
        YOUTUBE_VERTICAL_CHANNEL_DEPRECATED: int
        YOUTUBE_DEMOGRAPHIC_CHANNEL_DEPRECATED: int
        YOUTUBE_URL_UNSUPPORTED: int
        CANNOT_EXCLUDE_CRITERIA_TYPE: int
        CANNOT_ADD_CRITERIA_TYPE: int
        CANNOT_EXCLUDE_SIMILAR_USER_LIST: int
        CANNOT_ADD_CLOSED_USER_LIST: int
        CANNOT_ADD_DISPLAY_ONLY_LISTS_TO_SEARCH_ONLY_CAMPAIGNS: int
        CANNOT_ADD_DISPLAY_ONLY_LISTS_TO_SEARCH_CAMPAIGNS: int
        CANNOT_ADD_DISPLAY_ONLY_LISTS_TO_SHOPPING_CAMPAIGNS: int
        CANNOT_ADD_USER_INTERESTS_TO_SEARCH_CAMPAIGNS: int
        CANNOT_SET_BIDS_ON_CRITERION_TYPE_IN_SEARCH_CAMPAIGNS: int
        CANNOT_ADD_URLS_TO_CRITERION_TYPE_FOR_CAMPAIGN_TYPE: int
        INVALID_COMBINED_AUDIENCE: int
        INVALID_CUSTOM_AFFINITY: int
        INVALID_CUSTOM_INTENT: int
        INVALID_CUSTOM_AUDIENCE: int
        INVALID_IP_ADDRESS: int
        INVALID_IP_FORMAT: int
        INVALID_MOBILE_APP: int
        INVALID_MOBILE_APP_CATEGORY: int
        INVALID_CRITERION_ID: int
        CANNOT_TARGET_CRITERION: int
        CANNOT_TARGET_OBSOLETE_CRITERION: int
        CRITERION_ID_AND_TYPE_MISMATCH: int
        INVALID_PROXIMITY_RADIUS: int
        INVALID_PROXIMITY_RADIUS_UNITS: int
        INVALID_STREETADDRESS_LENGTH: int
        INVALID_CITYNAME_LENGTH: int
        INVALID_REGIONCODE_LENGTH: int
        INVALID_REGIONNAME_LENGTH: int
        INVALID_POSTALCODE_LENGTH: int
        INVALID_COUNTRY_CODE: int
        INVALID_LATITUDE: int
        INVALID_LONGITUDE: int
        PROXIMITY_GEOPOINT_AND_ADDRESS_BOTH_CANNOT_BE_NULL: int
        INVALID_PROXIMITY_ADDRESS: int
        INVALID_USER_DOMAIN_NAME: int
        CRITERION_PARAMETER_TOO_LONG: int
        AD_SCHEDULE_TIME_INTERVALS_OVERLAP: int
        AD_SCHEDULE_INTERVAL_CANNOT_SPAN_MULTIPLE_DAYS: int
        AD_SCHEDULE_INVALID_TIME_INTERVAL: int
        AD_SCHEDULE_EXCEEDED_INTERVALS_PER_DAY_LIMIT: int
        AD_SCHEDULE_CRITERION_ID_MISMATCHING_FIELDS: int
        CANNOT_BID_MODIFY_CRITERION_TYPE: int
        CANNOT_BID_MODIFY_CRITERION_CAMPAIGN_OPTED_OUT: int
        CANNOT_BID_MODIFY_NEGATIVE_CRITERION: int
        BID_MODIFIER_ALREADY_EXISTS: int
        FEED_ID_NOT_ALLOWED: int
        ACCOUNT_INELIGIBLE_FOR_CRITERIA_TYPE: int
        CRITERIA_TYPE_INVALID_FOR_BIDDING_STRATEGY: int
        CANNOT_EXCLUDE_CRITERION: int
        CANNOT_REMOVE_CRITERION: int
        INVALID_PRODUCT_BIDDING_CATEGORY: int
        MISSING_SHOPPING_SETTING: int
        INVALID_MATCHING_FUNCTION: int
        LOCATION_FILTER_NOT_ALLOWED: int
        INVALID_FEED_FOR_LOCATION_FILTER: int
        LOCATION_FILTER_INVALID: int
        CANNOT_SET_GEO_TARGET_CONSTANTS_WITH_FEED_ITEM_SETS: int
        INVALID_LOCATION_GROUP_RADIUS: int
        INVALID_LOCATION_GROUP_RADIUS_UNIT: int
        CANNOT_ATTACH_CRITERIA_AT_CAMPAIGN_AND_ADGROUP: int
        HOTEL_LENGTH_OF_STAY_OVERLAPS_WITH_EXISTING_CRITERION: int
        HOTEL_ADVANCE_BOOKING_WINDOW_OVERLAPS_WITH_EXISTING_CRITERION: int
        FIELD_INCOMPATIBLE_WITH_NEGATIVE_TARGETING: int
        INVALID_WEBPAGE_CONDITION: int
        INVALID_WEBPAGE_CONDITION_URL: int
        WEBPAGE_CONDITION_URL_CANNOT_BE_EMPTY: int
        WEBPAGE_CONDITION_URL_UNSUPPORTED_PROTOCOL: int
        WEBPAGE_CONDITION_URL_CANNOT_BE_IP_ADDRESS: int
        WEBPAGE_CONDITION_URL_DOMAIN_NOT_CONSISTENT_WITH_CAMPAIGN_SETTING: int
        WEBPAGE_CONDITION_URL_CANNOT_BE_PUBLIC_SUFFIX: int
        WEBPAGE_CONDITION_URL_INVALID_PUBLIC_SUFFIX: int
        WEBPAGE_CONDITION_URL_VALUE_TRACK_VALUE_NOT_SUPPORTED: int
        WEBPAGE_CRITERION_URL_EQUALS_CAN_HAVE_ONLY_ONE_CONDITION: int
        WEBPAGE_CRITERION_NOT_SUPPORTED_ON_NON_DSA_AD_GROUP: int
        CANNOT_TARGET_USER_LIST_FOR_SMART_DISPLAY_CAMPAIGNS: int
        CANNOT_TARGET_PLACEMENTS_FOR_SEARCH_CAMPAIGNS: int
        LISTING_SCOPE_TOO_MANY_DIMENSION_TYPES: int
        LISTING_SCOPE_TOO_MANY_IN_OPERATORS: int
        LISTING_SCOPE_IN_OPERATOR_NOT_SUPPORTED: int
        DUPLICATE_LISTING_DIMENSION_TYPE: int
        DUPLICATE_LISTING_DIMENSION_VALUE: int
        CANNOT_SET_BIDS_ON_LISTING_GROUP_SUBDIVISION: int
        INVALID_LISTING_GROUP_HIERARCHY: int
        LISTING_GROUP_UNIT_CANNOT_HAVE_CHILDREN: int
        LISTING_GROUP_SUBDIVISION_REQUIRES_OTHERS_CASE: int
        LISTING_GROUP_REQUIRES_SAME_DIMENSION_TYPE_AS_SIBLINGS: int
        LISTING_GROUP_ALREADY_EXISTS: int
        LISTING_GROUP_DOES_NOT_EXIST: int
        LISTING_GROUP_CANNOT_BE_REMOVED: int
        INVALID_LISTING_GROUP_TYPE: int
        LISTING_GROUP_ADD_MAY_ONLY_USE_TEMP_ID: int
        LISTING_SCOPE_TOO_LONG: int
        LISTING_SCOPE_TOO_MANY_DIMENSIONS: int
        LISTING_GROUP_TOO_LONG: int
        LISTING_GROUP_TREE_TOO_DEEP: int
        INVALID_LISTING_DIMENSION: int
        INVALID_LISTING_DIMENSION_TYPE: int
        ADVERTISER_NOT_ON_ALLOWLIST_FOR_COMBINED_AUDIENCE_ON_DISPLAY: int
        CANNOT_TARGET_REMOVED_COMBINED_AUDIENCE: int
        INVALID_COMBINED_AUDIENCE_ID: int
        CANNOT_TARGET_REMOVED_CUSTOM_AUDIENCE: int
        HOTEL_CHECK_IN_DATE_RANGE_OVERLAPS_WITH_EXISTING_CRITERION: int
        HOTEL_CHECK_IN_DATE_RANGE_START_DATE_TOO_EARLY: int
        HOTEL_CHECK_IN_DATE_RANGE_END_DATE_TOO_LATE: int
        HOTEL_CHECK_IN_DATE_RANGE_REVERSED: int
