from typing import Any

import proto

__protobuf__: Any

class InteractionTypeEnum(proto.Message):
    class InteractionType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        CALLS: int
