from typing import Any

import proto

__protobuf__: Any

class CurrencyCodeErrorEnum(proto.Message):
    class CurrencyCodeError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        UNSUPPORTED: int
