from .base import (
    HotelPerformanceViewServiceTransport as HotelPerformanceViewServiceTransport,
)
from .grpc import (
    HotelPerformanceViewServiceGrpcTransport as HotelPerformanceViewServiceGrpcTransport,
)
