from .base import (
    OperatingSystemVersionConstantServiceTransport as OperatingSystemVersionConstantServiceTransport,
)
from .grpc import (
    OperatingSystemVersionConstantServiceGrpcTransport as OperatingSystemVersionConstantServiceGrpcTransport,
)
