from typing import Any

import proto

__protobuf__: Any

class AdGroupCriterionErrorEnum(proto.Message):
    class AdGroupCriterionError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        AD_GROUP_CRITERION_LABEL_DOES_NOT_EXIST: int
        AD_GROUP_CRITERION_LABEL_ALREADY_EXISTS: int
        CANNOT_ADD_LABEL_TO_NEGATIVE_CRITERION: int
        TOO_MANY_OPERATIONS: int
        CANT_UPDATE_NEGATIVE: int
        CONCRETE_TYPE_REQUIRED: int
        BID_INCOMPATIBLE_WITH_ADGROUP: int
        CANNOT_TARGET_AND_EXCLUDE: int
        ILLEGAL_URL: int
        INVALID_KEYWORD_TEXT: int
        INVALID_DESTINATION_URL: int
        MISSING_DESTINATION_URL_TAG: int
        KEYWORD_LEVEL_BID_NOT_SUPPORTED_FOR_MANUALCPM: int
        INVALID_USER_STATUS: int
        CANNOT_ADD_CRITERIA_TYPE: int
        CANNOT_EXCLUDE_CRITERIA_TYPE: int
        CAMPAIGN_TYPE_NOT_COMPATIBLE_WITH_PARTIAL_FAILURE: int
        OPERATIONS_FOR_TOO_MANY_SHOPPING_ADGROUPS: int
        CANNOT_MODIFY_URL_FIELDS_WITH_DUPLICATE_ELEMENTS: int
        CANNOT_SET_WITHOUT_FINAL_URLS: int
        CANNOT_CLEAR_FINAL_URLS_IF_FINAL_MOBILE_URLS_EXIST: int
        CANNOT_CLEAR_FINAL_URLS_IF_FINAL_APP_URLS_EXIST: int
        CANNOT_CLEAR_FINAL_URLS_IF_TRACKING_URL_TEMPLATE_EXISTS: int
        CANNOT_CLEAR_FINAL_URLS_IF_URL_CUSTOM_PARAMETERS_EXIST: int
        CANNOT_SET_BOTH_DESTINATION_URL_AND_FINAL_URLS: int
        CANNOT_SET_BOTH_DESTINATION_URL_AND_TRACKING_URL_TEMPLATE: int
        FINAL_URLS_NOT_SUPPORTED_FOR_CRITERION_TYPE: int
        FINAL_MOBILE_URLS_NOT_SUPPORTED_FOR_CRITERION_TYPE: int
