from .base import (
    DetailPlacementViewServiceTransport as DetailPlacementViewServiceTransport,
)
from .grpc import (
    DetailPlacementViewServiceGrpcTransport as DetailPlacementViewServiceGrpcTransport,
)
