from typing import Any

import proto

__protobuf__: Any

class AffiliateLocationFeedRelationshipTypeEnum(proto.Message):
    class AffiliateLocationFeedRelationshipType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        GENERAL_RETAILER: int
