from typing import Any

import proto

__protobuf__: Any

class CallTrackingDisplayLocationEnum(proto.Message):
    class CallTrackingDisplayLocation(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        AD: int
        LANDING_PAGE: int
