from typing import Any

import proto

__protobuf__: Any

class FeedItemSetStringFilterTypeEnum(proto.Message):
    class FeedItemSetStringFilterType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        EXACT: int
