from typing import Any

import proto

__protobuf__: Any

class PricePlaceholderFieldEnum(proto.Message):
    class PricePlaceholderField(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        TYPE: int
        PRICE_QUALIFIER: int
        TRACKING_TEMPLATE: int
        LANGUAGE: int
        FINAL_URL_SUFFIX: int
        ITEM_1_HEADER: int
        ITEM_1_DESCRIPTION: int
        ITEM_1_PRICE: int
        ITEM_1_UNIT: int
        ITEM_1_FINAL_URLS: int
        ITEM_1_FINAL_MOBILE_URLS: int
        ITEM_2_HEADER: int
        ITEM_2_DESCRIPTION: int
        ITEM_2_PRICE: int
        ITEM_2_UNIT: int
        ITEM_2_FINAL_URLS: int
        ITEM_2_FINAL_MOBILE_URLS: int
        ITEM_3_HEADER: int
        ITEM_3_DESCRIPTION: int
        ITEM_3_PRICE: int
        ITEM_3_UNIT: int
        ITEM_3_FINAL_URLS: int
        ITEM_3_FINAL_MOBILE_URLS: int
        ITEM_4_HEADER: int
        ITEM_4_DESCRIPTION: int
        ITEM_4_PRICE: int
        ITEM_4_UNIT: int
        ITEM_4_FINAL_URLS: int
        ITEM_4_FINAL_MOBILE_URLS: int
        ITEM_5_HEADER: int
        ITEM_5_DESCRIPTION: int
        ITEM_5_PRICE: int
        ITEM_5_UNIT: int
        ITEM_5_FINAL_URLS: int
        ITEM_5_FINAL_MOBILE_URLS: int
        ITEM_6_HEADER: int
        ITEM_6_DESCRIPTION: int
        ITEM_6_PRICE: int
        ITEM_6_UNIT: int
        ITEM_6_FINAL_URLS: int
        ITEM_6_FINAL_MOBILE_URLS: int
        ITEM_7_HEADER: int
        ITEM_7_DESCRIPTION: int
        ITEM_7_PRICE: int
        ITEM_7_UNIT: int
        ITEM_7_FINAL_URLS: int
        ITEM_7_FINAL_MOBILE_URLS: int
        ITEM_8_HEADER: int
        ITEM_8_DESCRIPTION: int
        ITEM_8_PRICE: int
        ITEM_8_UNIT: int
        ITEM_8_FINAL_URLS: int
        ITEM_8_FINAL_MOBILE_URLS: int
