from typing import Any

import proto

from google.ads.googleads.v7.enums.types import geo_targeting_type as geo_targeting_type

__protobuf__: Any

class GeographicView(proto.Message):
    resource_name: Any
    location_type: Any
    country_criterion_id: Any
