from typing import Any

import proto

__protobuf__: Any

class BiddingErrorEnum(proto.Message):
    class BiddingError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        BIDDING_STRATEGY_TRANSITION_NOT_ALLOWED: int
        CANNOT_ATTACH_BIDDING_STRATEGY_TO_CAMPAIGN: int
        INVALID_ANONYMOUS_BIDDING_STRATEGY_TYPE: int
        INVALID_BIDDING_STRATEGY_TYPE: int
        INVALID_BID: int
        BIDDING_STRATEGY_NOT_AVAILABLE_FOR_ACCOUNT_TYPE: int
        CONVERSION_TRACKING_NOT_ENABLED: int
        NOT_ENOUGH_CONVERSIONS: int
        CANNOT_CREATE_CAMPAIGN_WITH_BIDDING_STRATEGY: int
        CANNOT_TARGET_CONTENT_NETWORK_ONLY_WITH_CAMPAIGN_LEVEL_POP_BIDDING_STRATEGY: int
        BIDDING_STRATEGY_NOT_SUPPORTED_WITH_AD_SCHEDULE: int
        PAY_PER_CONVERSION_NOT_AVAILABLE_FOR_CUSTOMER: int
        PAY_PER_CONVERSION_NOT_ALLOWED_WITH_TARGET_CPA: int
        BIDDING_STRATEGY_NOT_ALLOWED_FOR_SEARCH_ONLY_CAMPAIGNS: int
        BIDDING_STRATEGY_NOT_SUPPORTED_IN_DRAFTS_OR_EXPERIMENTS: int
        BIDDING_STRATEGY_TYPE_DOES_NOT_SUPPORT_PRODUCT_TYPE_ADGROUP_CRITERION: int
        BID_TOO_SMALL: int
        BID_TOO_BIG: int
        BID_TOO_MANY_FRACTIONAL_DIGITS: int
        INVALID_DOMAIN_NAME: int
        NOT_COMPATIBLE_WITH_PAYMENT_MODE: int
        NOT_COMPATIBLE_WITH_BUDGET_TYPE: int
        NOT_COMPATIBLE_WITH_BIDDING_STRATEGY_TYPE: int
        BIDDING_STRATEGY_TYPE_INCOMPATIBLE_WITH_SHARED_BUDGET: int
