from .base import (
    CampaignCriterionSimulationServiceTransport as CampaignCriterionSimulationServiceTransport,
)
from .grpc import (
    CampaignCriterionSimulationServiceGrpcTransport as CampaignCriterionSimulationServiceGrpcTransport,
)
