from .base import (
    AssetFieldTypeViewServiceTransport as AssetFieldTypeViewServiceTransport,
)
from .grpc import (
    AssetFieldTypeViewServiceGrpcTransport as AssetFieldTypeViewServiceGrpcTransport,
)
