from typing import Any

import proto

__protobuf__: Any

class KeywordPlanAdGroup(proto.Message):
    resource_name: Any
    keyword_plan_campaign: Any
    id: Any
    name: Any
    cpc_bid_micros: Any
