from typing import Any

import proto

__protobuf__: Any

class StructuredSnippetPlaceholderFieldEnum(proto.Message):
    class StructuredSnippetPlaceholderField(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        HEADER: int
        SNIPPETS: int
