from typing import Any

import proto

__protobuf__: Any

class UserListClosingReasonEnum(proto.Message):
    class UserListClosingReason(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        UNUSED: int
