from typing import Any

import proto

__protobuf__: Any

class KeywordPlanCompetitionLevelEnum(proto.Message):
    class KeywordPlanCompetitionLevel(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        LOW: int
        MEDIUM: int
        HIGH: int
