from typing import Any

import proto

__protobuf__: Any

class AssetLinkErrorEnum(proto.Message):
    class AssetLinkError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        PINNING_UNSUPPORTED: int
        UNSUPPORTED_FIELD_TYPE: int
        FIELD_TYPE_INCOMPATIBLE_WITH_ASSET_TYPE: int
        FIELD_TYPE_INCOMPATIBLE_WITH_CAMPAIGN_TYPE: int
        INCOMPATIBLE_ADVERTISING_CHANNEL_TYPE: int
        IMAGE_NOT_WITHIN_SPECIFIED_DIMENSION_RANGE: int
        INVALID_PINNED_FIELD: int
        MEDIA_BUNDLE_ASSET_FILE_SIZE_TOO_LARGE: int
        NOT_ENOUGH_AVAILABLE_ASSET_LINKS_FOR_VALID_COMBINATION: int
        NOT_ENOUGH_AVAILABLE_ASSET_LINKS_WITH_FALLBACK: int
        NOT_ENOUGH_AVAILABLE_ASSET_LINKS_WITH_FALLBACK_FOR_VALID_COMBINATION: int
        YOUTUBE_VIDEO_REMOVED: int
        YOUTUBE_VIDEO_TOO_LONG: int
        YOUTUBE_VIDEO_TOO_SHORT: int
        INVALID_STATUS: int
