from typing import Any

import proto

__protobuf__: Any

class AdGroupErrorEnum(proto.Message):
    class AdGroupError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        DUPLICATE_ADGROUP_NAME: int
        INVALID_ADGROUP_NAME: int
        ADVERTISER_NOT_ON_CONTENT_NETWORK: int
        BID_TOO_BIG: int
        BID_TYPE_AND_BIDDING_STRATEGY_MISMATCH: int
        MISSING_ADGROUP_NAME: int
        ADGROUP_LABEL_DOES_NOT_EXIST: int
        ADGROUP_LABEL_ALREADY_EXISTS: int
        INVALID_CONTENT_BID_CRITERION_TYPE_GROUP: int
        AD_GROUP_TYPE_NOT_VALID_FOR_ADVERTISING_CHANNEL_TYPE: int
        ADGROUP_TYPE_NOT_SUPPORTED_FOR_CAMPAIGN_SALES_COUNTRY: int
        CANNOT_ADD_ADGROUP_OF_TYPE_DSA_TO_CAMPAIGN_WITHOUT_DSA_SETTING: int
        PROMOTED_HOTEL_AD_GROUPS_NOT_AVAILABLE_FOR_CUSTOMER: int
        INVALID_EXCLUDED_PARENT_ASSET_FIELD_TYPE: int
