from typing import Any

import proto

from google.ads.googleads.v8.enums.types import asset_field_type as asset_field_type

__protobuf__: Any

class AssetFieldTypeView(proto.Message):
    resource_name: Any
    field_type: Any
