from typing import Any

import proto

from google.ads.googleads.v7.enums.types import mobile_device_type as mobile_device_type

__protobuf__: Any

class MobileDeviceConstant(proto.Message):
    resource_name: Any
    id: Any
    name: Any
    manufacturer_name: Any
    operating_system_name: Any
    type_: Any
