from typing import Any

import proto

from google.ads.googleads.v7.enums.types import keyword_match_type as keyword_match_type

__protobuf__: Any

class KeywordPlanAdGroupKeyword(proto.Message):
    resource_name: Any
    keyword_plan_ad_group: Any
    id: Any
    text: Any
    match_type: Any
    cpc_bid_micros: Any
    negative: Any
