from typing import Any

import proto

__protobuf__: Any

class MonthOfYearEnum(proto.Message):
    class MonthOfYear(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        JANUARY: int
        FEBRUARY: int
        MARCH: int
        APRIL: int
        MAY: int
        JUNE: int
        JULY: int
        AUGUST: int
        SEPTEMBER: int
        OCTOBER: int
        NOVEMBER: int
        DECEMBER: int
