from typing import Any

import proto

__protobuf__: Any

class PreferredContentTypeEnum(proto.Message):
    class PreferredContentType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        YOUTUBE_TOP_CONTENT: int
