from typing import Any

import proto

__protobuf__: Any

class CustomerClient(proto.Message):
    resource_name: Any
    client_customer: Any
    hidden: Any
    level: Any
    time_zone: Any
    test_account: Any
    manager: Any
    descriptive_name: Any
    currency_code: Any
    id: Any
    applied_labels: Any
