from typing import Any

import proto

__protobuf__: Any

class ConversionAdjustmentTypeEnum(proto.Message):
    class ConversionAdjustmentType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        RETRACTION: int
        RESTATEMENT: int
