from typing import Any

import proto

__protobuf__: Any

class SystemManagedResourceSourceEnum(proto.Message):
    class SystemManagedResourceSource(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        AD_VARIATIONS: int
