from typing import Any

import proto

__protobuf__: Any

class ProductTypeLevelEnum(proto.Message):
    class ProductTypeLevel(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        LEVEL1: int
        LEVEL2: int
        LEVEL3: int
        LEVEL4: int
        LEVEL5: int
