from .base import (
    DetailedDemographicServiceTransport as DetailedDemographicServiceTransport,
)
from .grpc import (
    DetailedDemographicServiceGrpcTransport as DetailedDemographicServiceGrpcTransport,
)
