from typing import Any

import proto

__protobuf__: Any

class ServedAssetFieldTypeEnum(proto.Message):
    class ServedAssetFieldType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        HEADLINE_1: int
        HEADLINE_2: int
        HEADLINE_3: int
        DESCRIPTION_1: int
        DESCRIPTION_2: int
