from typing import Any

import proto

__protobuf__: Any

class DomainCategory(proto.Message):
    resource_name: Any
    campaign: Any
    category: Any
    language_code: Any
    domain: Any
    coverage_fraction: Any
    category_rank: Any
    has_children: Any
    recommended_cpc_bid_micros: Any
