from typing import Any

import proto

__protobuf__: Any

class GeoTargetingRestrictionEnum(proto.Message):
    class GeoTargetingRestriction(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        LOCATION_OF_PRESENCE: int
