from typing import Any

import proto

__protobuf__: Any

class ExtensionSettingErrorEnum(proto.Message):
    class ExtensionSettingError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        EXTENSIONS_REQUIRED: int
        FEED_TYPE_EXTENSION_TYPE_MISMATCH: int
        INVALID_FEED_TYPE: int
        INVALID_FEED_TYPE_FOR_CUSTOMER_EXTENSION_SETTING: int
        CANNOT_CHANGE_FEED_ITEM_ON_CREATE: int
        CANNOT_UPDATE_NEWLY_CREATED_EXTENSION: int
        NO_EXISTING_AD_GROUP_EXTENSION_SETTING_FOR_TYPE: int
        NO_EXISTING_CAMPAIGN_EXTENSION_SETTING_FOR_TYPE: int
        NO_EXISTING_CUSTOMER_EXTENSION_SETTING_FOR_TYPE: int
        AD_GROUP_EXTENSION_SETTING_ALREADY_EXISTS: int
        CAMPAIGN_EXTENSION_SETTING_ALREADY_EXISTS: int
        CUSTOMER_EXTENSION_SETTING_ALREADY_EXISTS: int
        AD_GROUP_FEED_ALREADY_EXISTS_FOR_PLACEHOLDER_TYPE: int
        CAMPAIGN_FEED_ALREADY_EXISTS_FOR_PLACEHOLDER_TYPE: int
        CUSTOMER_FEED_ALREADY_EXISTS_FOR_PLACEHOLDER_TYPE: int
        VALUE_OUT_OF_RANGE: int
        CANNOT_SET_FIELD_WITH_FINAL_URLS: int
        FINAL_URLS_NOT_SET: int
        INVALID_PHONE_NUMBER: int
        PHONE_NUMBER_NOT_SUPPORTED_FOR_COUNTRY: int
        CARRIER_SPECIFIC_SHORT_NUMBER_NOT_ALLOWED: int
        PREMIUM_RATE_NUMBER_NOT_ALLOWED: int
        DISALLOWED_NUMBER_TYPE: int
        INVALID_DOMESTIC_PHONE_NUMBER_FORMAT: int
        VANITY_PHONE_NUMBER_NOT_ALLOWED: int
        INVALID_COUNTRY_CODE: int
        INVALID_CALL_CONVERSION_TYPE_ID: int
        CUSTOMER_NOT_IN_ALLOWLIST_FOR_CALLTRACKING: int
        CALLTRACKING_NOT_SUPPORTED_FOR_COUNTRY: int
        INVALID_APP_ID: int
        QUOTES_IN_REVIEW_EXTENSION_SNIPPET: int
        HYPHENS_IN_REVIEW_EXTENSION_SNIPPET: int
        REVIEW_EXTENSION_SOURCE_NOT_ELIGIBLE: int
        SOURCE_NAME_IN_REVIEW_EXTENSION_TEXT: int
        MISSING_FIELD: int
        INCONSISTENT_CURRENCY_CODES: int
        PRICE_EXTENSION_HAS_DUPLICATED_HEADERS: int
        PRICE_ITEM_HAS_DUPLICATED_HEADER_AND_DESCRIPTION: int
        PRICE_EXTENSION_HAS_TOO_FEW_ITEMS: int
        PRICE_EXTENSION_HAS_TOO_MANY_ITEMS: int
        UNSUPPORTED_VALUE: int
        INVALID_DEVICE_PREFERENCE: int
        INVALID_SCHEDULE_END: int
        DATE_TIME_MUST_BE_IN_ACCOUNT_TIME_ZONE: int
        OVERLAPPING_SCHEDULES_NOT_ALLOWED: int
        SCHEDULE_END_NOT_AFTER_START: int
        TOO_MANY_SCHEDULES_PER_DAY: int
        DUPLICATE_EXTENSION_FEED_ITEM_EDIT: int
        INVALID_SNIPPETS_HEADER: int
        PHONE_NUMBER_NOT_SUPPORTED_WITH_CALLTRACKING_FOR_COUNTRY: int
        CAMPAIGN_TARGETING_MISMATCH: int
        CANNOT_OPERATE_ON_REMOVED_FEED: int
        EXTENSION_TYPE_REQUIRED: int
        INCOMPATIBLE_UNDERLYING_MATCHING_FUNCTION: int
        START_DATE_AFTER_END_DATE: int
        INVALID_PRICE_FORMAT: int
        PROMOTION_INVALID_TIME: int
        PROMOTION_CANNOT_SET_PERCENT_DISCOUNT_AND_MONEY_DISCOUNT: int
        PROMOTION_CANNOT_SET_PROMOTION_CODE_AND_ORDERS_OVER_AMOUNT: int
        TOO_MANY_DECIMAL_PLACES_SPECIFIED: int
        INVALID_LANGUAGE_CODE: int
        UNSUPPORTED_LANGUAGE: int
        CUSTOMER_CONSENT_FOR_CALL_RECORDING_REQUIRED: int
        EXTENSION_SETTING_UPDATE_IS_A_NOOP: int
        DISALLOWED_TEXT: int
