from typing import Any

import proto

__protobuf__: Any

class VanityPharmaTextEnum(proto.Message):
    class VanityPharmaText(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        PRESCRIPTION_TREATMENT_WEBSITE_EN: int
        PRESCRIPTION_TREATMENT_WEBSITE_ES: int
        PRESCRIPTION_DEVICE_WEBSITE_EN: int
        PRESCRIPTION_DEVICE_WEBSITE_ES: int
        MEDICAL_DEVICE_WEBSITE_EN: int
        MEDICAL_DEVICE_WEBSITE_ES: int
        PREVENTATIVE_TREATMENT_WEBSITE_EN: int
        PREVENTATIVE_TREATMENT_WEBSITE_ES: int
        PRESCRIPTION_CONTRACEPTION_WEBSITE_EN: int
        PRESCRIPTION_CONTRACEPTION_WEBSITE_ES: int
        PRESCRIPTION_VACCINE_WEBSITE_EN: int
        PRESCRIPTION_VACCINE_WEBSITE_ES: int
