from .base import (
    PaidOrganicSearchTermViewServiceTransport as PaidOrganicSearchTermViewServiceTransport,
)
from .grpc import (
    PaidOrganicSearchTermViewServiceGrpcTransport as PaidOrganicSearchTermViewServiceGrpcTransport,
)
