from typing import Any

import proto

__protobuf__: Any

class AdErrorEnum(proto.Message):
    class AdError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        AD_CUSTOMIZERS_NOT_SUPPORTED_FOR_AD_TYPE: int
        APPROXIMATELY_TOO_LONG: int
        APPROXIMATELY_TOO_SHORT: int
        BAD_SNIPPET: int
        CANNOT_MODIFY_AD: int
        CANNOT_SET_BUSINESS_NAME_IF_URL_SET: int
        CANNOT_SET_FIELD: int
        CANNOT_SET_FIELD_WITH_ORIGIN_AD_ID_SET: int
        CANNOT_SET_FIELD_WITH_AD_ID_SET_FOR_SHARING: int
        CANNOT_SET_ALLOW_FLEXIBLE_COLOR_FALSE: int
        CANNOT_SET_COLOR_CONTROL_WHEN_NATIVE_FORMAT_SETTING: int
        CANNOT_SET_URL: int
        CANNOT_SET_WITHOUT_FINAL_URLS: int
        CANNOT_SET_WITH_FINAL_URLS: int
        CANNOT_SET_WITH_URL_DATA: int
        CANNOT_USE_AD_SUBCLASS_FOR_OPERATOR: int
        CUSTOMER_NOT_APPROVED_MOBILEADS: int
        CUSTOMER_NOT_APPROVED_THIRDPARTY_ADS: int
        CUSTOMER_NOT_APPROVED_THIRDPARTY_REDIRECT_ADS: int
        CUSTOMER_NOT_ELIGIBLE: int
        CUSTOMER_NOT_ELIGIBLE_FOR_UPDATING_BEACON_URL: int
        DIMENSION_ALREADY_IN_UNION: int
        DIMENSION_MUST_BE_SET: int
        DIMENSION_NOT_IN_UNION: int
        DISPLAY_URL_CANNOT_BE_SPECIFIED: int
        DOMESTIC_PHONE_NUMBER_FORMAT: int
        EMERGENCY_PHONE_NUMBER: int
        EMPTY_FIELD: int
        FEED_ATTRIBUTE_MUST_HAVE_MAPPING_FOR_TYPE_ID: int
        FEED_ATTRIBUTE_MAPPING_TYPE_MISMATCH: int
        ILLEGAL_AD_CUSTOMIZER_TAG_USE: int
        ILLEGAL_TAG_USE: int
        INCONSISTENT_DIMENSIONS: int
        INCONSISTENT_STATUS_IN_TEMPLATE_UNION: int
        INCORRECT_LENGTH: int
        INELIGIBLE_FOR_UPGRADE: int
        INVALID_AD_ADDRESS_CAMPAIGN_TARGET: int
        INVALID_AD_TYPE: int
        INVALID_ATTRIBUTES_FOR_MOBILE_IMAGE: int
        INVALID_ATTRIBUTES_FOR_MOBILE_TEXT: int
        INVALID_CALL_TO_ACTION_TEXT: int
        INVALID_CHARACTER_FOR_URL: int
        INVALID_COUNTRY_CODE: int
        INVALID_EXPANDED_DYNAMIC_SEARCH_AD_TAG: int
        INVALID_INPUT: int
        INVALID_MARKUP_LANGUAGE: int
        INVALID_MOBILE_CARRIER: int
        INVALID_MOBILE_CARRIER_TARGET: int
        INVALID_NUMBER_OF_ELEMENTS: int
        INVALID_PHONE_NUMBER_FORMAT: int
        INVALID_RICH_MEDIA_CERTIFIED_VENDOR_FORMAT_ID: int
        INVALID_TEMPLATE_DATA: int
        INVALID_TEMPLATE_ELEMENT_FIELD_TYPE: int
        INVALID_TEMPLATE_ID: int
        LINE_TOO_WIDE: int
        MISSING_AD_CUSTOMIZER_MAPPING: int
        MISSING_ADDRESS_COMPONENT: int
        MISSING_ADVERTISEMENT_NAME: int
        MISSING_BUSINESS_NAME: int
        MISSING_DESCRIPTION1: int
        MISSING_DESCRIPTION2: int
        MISSING_DESTINATION_URL_TAG: int
        MISSING_LANDING_PAGE_URL_TAG: int
        MISSING_DIMENSION: int
        MISSING_DISPLAY_URL: int
        MISSING_HEADLINE: int
        MISSING_HEIGHT: int
        MISSING_IMAGE: int
        MISSING_MARKETING_IMAGE_OR_PRODUCT_VIDEOS: int
        MISSING_MARKUP_LANGUAGES: int
        MISSING_MOBILE_CARRIER: int
        MISSING_PHONE: int
        MISSING_REQUIRED_TEMPLATE_FIELDS: int
        MISSING_TEMPLATE_FIELD_VALUE: int
        MISSING_TEXT: int
        MISSING_VISIBLE_URL: int
        MISSING_WIDTH: int
        MULTIPLE_DISTINCT_FEEDS_UNSUPPORTED: int
        MUST_USE_TEMP_AD_UNION_ID_ON_ADD: int
        TOO_LONG: int
        TOO_SHORT: int
        UNION_DIMENSIONS_CANNOT_CHANGE: int
        UNKNOWN_ADDRESS_COMPONENT: int
        UNKNOWN_FIELD_NAME: int
        UNKNOWN_UNIQUE_NAME: int
        UNSUPPORTED_DIMENSIONS: int
        URL_INVALID_SCHEME: int
        URL_INVALID_TOP_LEVEL_DOMAIN: int
        URL_MALFORMED: int
        URL_NO_HOST: int
        URL_NOT_EQUIVALENT: int
        URL_HOST_NAME_TOO_LONG: int
        URL_NO_SCHEME: int
        URL_NO_TOP_LEVEL_DOMAIN: int
        URL_PATH_NOT_ALLOWED: int
        URL_PORT_NOT_ALLOWED: int
        URL_QUERY_NOT_ALLOWED: int
        URL_SCHEME_BEFORE_EXPANDED_DYNAMIC_SEARCH_AD_TAG: int
        USER_DOES_NOT_HAVE_ACCESS_TO_TEMPLATE: int
        INCONSISTENT_EXPANDABLE_SETTINGS: int
        INVALID_FORMAT: int
        INVALID_FIELD_TEXT: int
        ELEMENT_NOT_PRESENT: int
        IMAGE_ERROR: int
        VALUE_NOT_IN_RANGE: int
        FIELD_NOT_PRESENT: int
        ADDRESS_NOT_COMPLETE: int
        ADDRESS_INVALID: int
        VIDEO_RETRIEVAL_ERROR: int
        AUDIO_ERROR: int
        INVALID_YOUTUBE_DISPLAY_URL: int
        TOO_MANY_PRODUCT_IMAGES: int
        TOO_MANY_PRODUCT_VIDEOS: int
        INCOMPATIBLE_AD_TYPE_AND_DEVICE_PREFERENCE: int
        CALLTRACKING_NOT_SUPPORTED_FOR_COUNTRY: int
        CARRIER_SPECIFIC_SHORT_NUMBER_NOT_ALLOWED: int
        DISALLOWED_NUMBER_TYPE: int
        PHONE_NUMBER_NOT_SUPPORTED_FOR_COUNTRY: int
        PHONE_NUMBER_NOT_SUPPORTED_WITH_CALLTRACKING_FOR_COUNTRY: int
        PREMIUM_RATE_NUMBER_NOT_ALLOWED: int
        VANITY_PHONE_NUMBER_NOT_ALLOWED: int
        INVALID_CALL_CONVERSION_TYPE_ID: int
        CANNOT_DISABLE_CALL_CONVERSION_AND_SET_CONVERSION_TYPE_ID: int
        CANNOT_SET_PATH2_WITHOUT_PATH1: int
        MISSING_DYNAMIC_SEARCH_ADS_SETTING_DOMAIN_NAME: int
        INCOMPATIBLE_WITH_RESTRICTION_TYPE: int
        CUSTOMER_CONSENT_FOR_CALL_RECORDING_REQUIRED: int
        MISSING_IMAGE_OR_MEDIA_BUNDLE: int
        PRODUCT_TYPE_NOT_SUPPORTED_IN_THIS_CAMPAIGN: int
        PLACEHOLDER_CANNOT_HAVE_EMPTY_DEFAULT_VALUE: int
        PLACEHOLDER_COUNTDOWN_FUNCTION_CANNOT_HAVE_DEFAULT_VALUE: int
        PLACEHOLDER_DEFAULT_VALUE_MISSING: int
        UNEXPECTED_PLACEHOLDER_DEFAULT_VALUE: int
        AD_CUSTOMIZERS_MAY_NOT_BE_ADJACENT: int
        UPDATING_AD_WITH_NO_ENABLED_ASSOCIATION: int
        TOO_MANY_AD_CUSTOMIZERS: int
        INVALID_AD_CUSTOMIZER_FORMAT: int
        NESTED_AD_CUSTOMIZER_SYNTAX: int
        UNSUPPORTED_AD_CUSTOMIZER_SYNTAX: int
        UNPAIRED_BRACE_IN_AD_CUSTOMIZER_TAG: int
        MORE_THAN_ONE_COUNTDOWN_TAG_TYPE_EXISTS: int
        DATE_TIME_IN_COUNTDOWN_TAG_IS_INVALID: int
        DATE_TIME_IN_COUNTDOWN_TAG_IS_PAST: int
        UNRECOGNIZED_AD_CUSTOMIZER_TAG_FOUND: int
        STORE_MISMATCH: int
        MISSING_REQUIRED_IMAGE_ASPECT_RATIO: int
