from .base import (
    ShoppingPerformanceViewServiceTransport as ShoppingPerformanceViewServiceTransport,
)
from .grpc import (
    ShoppingPerformanceViewServiceGrpcTransport as ShoppingPerformanceViewServiceGrpcTransport,
)
