# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['google-stubs']

package_data = \
{'': ['*'],
 'google-stubs': ['ads/googleads/*',
                  'ads/googleads/interceptors/*',
                  'ads/googleads/v7/*',
                  'ads/googleads/v7/common/*',
                  'ads/googleads/v7/common/services/*',
                  'ads/googleads/v7/common/types/*',
                  'ads/googleads/v7/enums/*',
                  'ads/googleads/v7/enums/services/*',
                  'ads/googleads/v7/enums/types/*',
                  'ads/googleads/v7/errors/*',
                  'ads/googleads/v7/errors/services/*',
                  'ads/googleads/v7/errors/types/*',
                  'ads/googleads/v7/resources/*',
                  'ads/googleads/v7/resources/services/*',
                  'ads/googleads/v7/resources/types/*',
                  'ads/googleads/v7/services/*',
                  'ads/googleads/v7/services/services/*',
                  'ads/googleads/v7/services/services/account_budget_proposal_service/*',
                  'ads/googleads/v7/services/services/account_budget_proposal_service/transports/*',
                  'ads/googleads/v7/services/services/account_budget_service/*',
                  'ads/googleads/v7/services/services/account_budget_service/transports/*',
                  'ads/googleads/v7/services/services/account_link_service/*',
                  'ads/googleads/v7/services/services/account_link_service/transports/*',
                  'ads/googleads/v7/services/services/ad_group_ad_asset_view_service/*',
                  'ads/googleads/v7/services/services/ad_group_ad_asset_view_service/transports/*',
                  'ads/googleads/v7/services/services/ad_group_ad_label_service/*',
                  'ads/googleads/v7/services/services/ad_group_ad_label_service/transports/*',
                  'ads/googleads/v7/services/services/ad_group_ad_service/*',
                  'ads/googleads/v7/services/services/ad_group_ad_service/transports/*',
                  'ads/googleads/v7/services/services/ad_group_asset_service/*',
                  'ads/googleads/v7/services/services/ad_group_asset_service/transports/*',
                  'ads/googleads/v7/services/services/ad_group_audience_view_service/*',
                  'ads/googleads/v7/services/services/ad_group_audience_view_service/transports/*',
                  'ads/googleads/v7/services/services/ad_group_bid_modifier_service/*',
                  'ads/googleads/v7/services/services/ad_group_bid_modifier_service/transports/*',
                  'ads/googleads/v7/services/services/ad_group_criterion_label_service/*',
                  'ads/googleads/v7/services/services/ad_group_criterion_label_service/transports/*',
                  'ads/googleads/v7/services/services/ad_group_criterion_service/*',
                  'ads/googleads/v7/services/services/ad_group_criterion_service/transports/*',
                  'ads/googleads/v7/services/services/ad_group_criterion_simulation_service/*',
                  'ads/googleads/v7/services/services/ad_group_criterion_simulation_service/transports/*',
                  'ads/googleads/v7/services/services/ad_group_extension_setting_service/*',
                  'ads/googleads/v7/services/services/ad_group_extension_setting_service/transports/*',
                  'ads/googleads/v7/services/services/ad_group_feed_service/*',
                  'ads/googleads/v7/services/services/ad_group_feed_service/transports/*',
                  'ads/googleads/v7/services/services/ad_group_label_service/*',
                  'ads/googleads/v7/services/services/ad_group_label_service/transports/*',
                  'ads/googleads/v7/services/services/ad_group_service/*',
                  'ads/googleads/v7/services/services/ad_group_service/transports/*',
                  'ads/googleads/v7/services/services/ad_group_simulation_service/*',
                  'ads/googleads/v7/services/services/ad_group_simulation_service/transports/*',
                  'ads/googleads/v7/services/services/ad_parameter_service/*',
                  'ads/googleads/v7/services/services/ad_parameter_service/transports/*',
                  'ads/googleads/v7/services/services/ad_schedule_view_service/*',
                  'ads/googleads/v7/services/services/ad_schedule_view_service/transports/*',
                  'ads/googleads/v7/services/services/ad_service/*',
                  'ads/googleads/v7/services/services/ad_service/transports/*',
                  'ads/googleads/v7/services/services/age_range_view_service/*',
                  'ads/googleads/v7/services/services/age_range_view_service/transports/*',
                  'ads/googleads/v7/services/services/asset_service/*',
                  'ads/googleads/v7/services/services/asset_service/transports/*',
                  'ads/googleads/v7/services/services/batch_job_service/*',
                  'ads/googleads/v7/services/services/batch_job_service/transports/*',
                  'ads/googleads/v7/services/services/bidding_strategy_service/*',
                  'ads/googleads/v7/services/services/bidding_strategy_service/transports/*',
                  'ads/googleads/v7/services/services/bidding_strategy_simulation_service/*',
                  'ads/googleads/v7/services/services/bidding_strategy_simulation_service/transports/*',
                  'ads/googleads/v7/services/services/billing_setup_service/*',
                  'ads/googleads/v7/services/services/billing_setup_service/transports/*',
                  'ads/googleads/v7/services/services/campaign_asset_service/*',
                  'ads/googleads/v7/services/services/campaign_asset_service/transports/*',
                  'ads/googleads/v7/services/services/campaign_audience_view_service/*',
                  'ads/googleads/v7/services/services/campaign_audience_view_service/transports/*',
                  'ads/googleads/v7/services/services/campaign_bid_modifier_service/*',
                  'ads/googleads/v7/services/services/campaign_bid_modifier_service/transports/*',
                  'ads/googleads/v7/services/services/campaign_budget_service/*',
                  'ads/googleads/v7/services/services/campaign_budget_service/transports/*',
                  'ads/googleads/v7/services/services/campaign_criterion_service/*',
                  'ads/googleads/v7/services/services/campaign_criterion_service/transports/*',
                  'ads/googleads/v7/services/services/campaign_criterion_simulation_service/*',
                  'ads/googleads/v7/services/services/campaign_criterion_simulation_service/transports/*',
                  'ads/googleads/v7/services/services/campaign_draft_service/*',
                  'ads/googleads/v7/services/services/campaign_draft_service/transports/*',
                  'ads/googleads/v7/services/services/campaign_experiment_service/*',
                  'ads/googleads/v7/services/services/campaign_experiment_service/transports/*',
                  'ads/googleads/v7/services/services/campaign_extension_setting_service/*',
                  'ads/googleads/v7/services/services/campaign_extension_setting_service/transports/*',
                  'ads/googleads/v7/services/services/campaign_feed_service/*',
                  'ads/googleads/v7/services/services/campaign_feed_service/transports/*',
                  'ads/googleads/v7/services/services/campaign_label_service/*',
                  'ads/googleads/v7/services/services/campaign_label_service/transports/*',
                  'ads/googleads/v7/services/services/campaign_service/*',
                  'ads/googleads/v7/services/services/campaign_service/transports/*',
                  'ads/googleads/v7/services/services/campaign_shared_set_service/*',
                  'ads/googleads/v7/services/services/campaign_shared_set_service/transports/*',
                  'ads/googleads/v7/services/services/campaign_simulation_service/*',
                  'ads/googleads/v7/services/services/campaign_simulation_service/transports/*',
                  'ads/googleads/v7/services/services/carrier_constant_service/*',
                  'ads/googleads/v7/services/services/carrier_constant_service/transports/*',
                  'ads/googleads/v7/services/services/change_status_service/*',
                  'ads/googleads/v7/services/services/change_status_service/transports/*',
                  'ads/googleads/v7/services/services/click_view_service/*',
                  'ads/googleads/v7/services/services/click_view_service/transports/*',
                  'ads/googleads/v7/services/services/combined_audience_service/*',
                  'ads/googleads/v7/services/services/combined_audience_service/transports/*',
                  'ads/googleads/v7/services/services/conversion_action_service/*',
                  'ads/googleads/v7/services/services/conversion_action_service/transports/*',
                  'ads/googleads/v7/services/services/conversion_adjustment_upload_service/*',
                  'ads/googleads/v7/services/services/conversion_adjustment_upload_service/transports/*',
                  'ads/googleads/v7/services/services/conversion_custom_variable_service/*',
                  'ads/googleads/v7/services/services/conversion_custom_variable_service/transports/*',
                  'ads/googleads/v7/services/services/conversion_upload_service/*',
                  'ads/googleads/v7/services/services/conversion_upload_service/transports/*',
                  'ads/googleads/v7/services/services/currency_constant_service/*',
                  'ads/googleads/v7/services/services/currency_constant_service/transports/*',
                  'ads/googleads/v7/services/services/custom_audience_service/*',
                  'ads/googleads/v7/services/services/custom_audience_service/transports/*',
                  'ads/googleads/v7/services/services/custom_interest_service/*',
                  'ads/googleads/v7/services/services/custom_interest_service/transports/*',
                  'ads/googleads/v7/services/services/customer_asset_service/*',
                  'ads/googleads/v7/services/services/customer_asset_service/transports/*',
                  'ads/googleads/v7/services/services/customer_client_link_service/*',
                  'ads/googleads/v7/services/services/customer_client_link_service/transports/*',
                  'ads/googleads/v7/services/services/customer_client_service/*',
                  'ads/googleads/v7/services/services/customer_client_service/transports/*',
                  'ads/googleads/v7/services/services/customer_extension_setting_service/*',
                  'ads/googleads/v7/services/services/customer_extension_setting_service/transports/*',
                  'ads/googleads/v7/services/services/customer_feed_service/*',
                  'ads/googleads/v7/services/services/customer_feed_service/transports/*',
                  'ads/googleads/v7/services/services/customer_label_service/*',
                  'ads/googleads/v7/services/services/customer_label_service/transports/*',
                  'ads/googleads/v7/services/services/customer_manager_link_service/*',
                  'ads/googleads/v7/services/services/customer_manager_link_service/transports/*',
                  'ads/googleads/v7/services/services/customer_negative_criterion_service/*',
                  'ads/googleads/v7/services/services/customer_negative_criterion_service/transports/*',
                  'ads/googleads/v7/services/services/customer_service/*',
                  'ads/googleads/v7/services/services/customer_service/transports/*',
                  'ads/googleads/v7/services/services/customer_user_access_invitation_service/*',
                  'ads/googleads/v7/services/services/customer_user_access_invitation_service/transports/*',
                  'ads/googleads/v7/services/services/customer_user_access_service/*',
                  'ads/googleads/v7/services/services/customer_user_access_service/transports/*',
                  'ads/googleads/v7/services/services/detail_placement_view_service/*',
                  'ads/googleads/v7/services/services/detail_placement_view_service/transports/*',
                  'ads/googleads/v7/services/services/display_keyword_view_service/*',
                  'ads/googleads/v7/services/services/display_keyword_view_service/transports/*',
                  'ads/googleads/v7/services/services/distance_view_service/*',
                  'ads/googleads/v7/services/services/distance_view_service/transports/*',
                  'ads/googleads/v7/services/services/domain_category_service/*',
                  'ads/googleads/v7/services/services/domain_category_service/transports/*',
                  'ads/googleads/v7/services/services/dynamic_search_ads_search_term_view_service/*',
                  'ads/googleads/v7/services/services/dynamic_search_ads_search_term_view_service/transports/*',
                  'ads/googleads/v7/services/services/expanded_landing_page_view_service/*',
                  'ads/googleads/v7/services/services/expanded_landing_page_view_service/transports/*',
                  'ads/googleads/v7/services/services/extension_feed_item_service/*',
                  'ads/googleads/v7/services/services/extension_feed_item_service/transports/*',
                  'ads/googleads/v7/services/services/feed_item_service/*',
                  'ads/googleads/v7/services/services/feed_item_service/transports/*',
                  'ads/googleads/v7/services/services/feed_item_set_link_service/*',
                  'ads/googleads/v7/services/services/feed_item_set_link_service/transports/*',
                  'ads/googleads/v7/services/services/feed_item_set_service/*',
                  'ads/googleads/v7/services/services/feed_item_set_service/transports/*',
                  'ads/googleads/v7/services/services/feed_item_target_service/*',
                  'ads/googleads/v7/services/services/feed_item_target_service/transports/*',
                  'ads/googleads/v7/services/services/feed_mapping_service/*',
                  'ads/googleads/v7/services/services/feed_mapping_service/transports/*',
                  'ads/googleads/v7/services/services/feed_placeholder_view_service/*',
                  'ads/googleads/v7/services/services/feed_placeholder_view_service/transports/*',
                  'ads/googleads/v7/services/services/feed_service/*',
                  'ads/googleads/v7/services/services/feed_service/transports/*',
                  'ads/googleads/v7/services/services/gender_view_service/*',
                  'ads/googleads/v7/services/services/gender_view_service/transports/*',
                  'ads/googleads/v7/services/services/geo_target_constant_service/*',
                  'ads/googleads/v7/services/services/geo_target_constant_service/transports/*',
                  'ads/googleads/v7/services/services/geographic_view_service/*',
                  'ads/googleads/v7/services/services/geographic_view_service/transports/*',
                  'ads/googleads/v7/services/services/google_ads_field_service/*',
                  'ads/googleads/v7/services/services/google_ads_field_service/transports/*',
                  'ads/googleads/v7/services/services/google_ads_service/*',
                  'ads/googleads/v7/services/services/google_ads_service/transports/*',
                  'ads/googleads/v7/services/services/group_placement_view_service/*',
                  'ads/googleads/v7/services/services/group_placement_view_service/transports/*',
                  'ads/googleads/v7/services/services/hotel_group_view_service/*',
                  'ads/googleads/v7/services/services/hotel_group_view_service/transports/*',
                  'ads/googleads/v7/services/services/hotel_performance_view_service/*',
                  'ads/googleads/v7/services/services/hotel_performance_view_service/transports/*',
                  'ads/googleads/v7/services/services/income_range_view_service/*',
                  'ads/googleads/v7/services/services/income_range_view_service/transports/*',
                  'ads/googleads/v7/services/services/invoice_service/*',
                  'ads/googleads/v7/services/services/invoice_service/transports/*',
                  'ads/googleads/v7/services/services/keyword_plan_ad_group_keyword_service/*',
                  'ads/googleads/v7/services/services/keyword_plan_ad_group_keyword_service/transports/*',
                  'ads/googleads/v7/services/services/keyword_plan_ad_group_service/*',
                  'ads/googleads/v7/services/services/keyword_plan_ad_group_service/transports/*',
                  'ads/googleads/v7/services/services/keyword_plan_campaign_keyword_service/*',
                  'ads/googleads/v7/services/services/keyword_plan_campaign_keyword_service/transports/*',
                  'ads/googleads/v7/services/services/keyword_plan_campaign_service/*',
                  'ads/googleads/v7/services/services/keyword_plan_campaign_service/transports/*',
                  'ads/googleads/v7/services/services/keyword_plan_idea_service/*',
                  'ads/googleads/v7/services/services/keyword_plan_idea_service/transports/*',
                  'ads/googleads/v7/services/services/keyword_plan_service/*',
                  'ads/googleads/v7/services/services/keyword_plan_service/transports/*',
                  'ads/googleads/v7/services/services/keyword_view_service/*',
                  'ads/googleads/v7/services/services/keyword_view_service/transports/*',
                  'ads/googleads/v7/services/services/label_service/*',
                  'ads/googleads/v7/services/services/label_service/transports/*',
                  'ads/googleads/v7/services/services/landing_page_view_service/*',
                  'ads/googleads/v7/services/services/landing_page_view_service/transports/*',
                  'ads/googleads/v7/services/services/language_constant_service/*',
                  'ads/googleads/v7/services/services/language_constant_service/transports/*',
                  'ads/googleads/v7/services/services/life_event_service/*',
                  'ads/googleads/v7/services/services/life_event_service/transports/*',
                  'ads/googleads/v7/services/services/location_view_service/*',
                  'ads/googleads/v7/services/services/location_view_service/transports/*',
                  'ads/googleads/v7/services/services/managed_placement_view_service/*',
                  'ads/googleads/v7/services/services/managed_placement_view_service/transports/*',
                  'ads/googleads/v7/services/services/media_file_service/*',
                  'ads/googleads/v7/services/services/media_file_service/transports/*',
                  'ads/googleads/v7/services/services/merchant_center_link_service/*',
                  'ads/googleads/v7/services/services/merchant_center_link_service/transports/*',
                  'ads/googleads/v7/services/services/mobile_app_category_constant_service/*',
                  'ads/googleads/v7/services/services/mobile_app_category_constant_service/transports/*',
                  'ads/googleads/v7/services/services/mobile_device_constant_service/*',
                  'ads/googleads/v7/services/services/mobile_device_constant_service/transports/*',
                  'ads/googleads/v7/services/services/offline_user_data_job_service/*',
                  'ads/googleads/v7/services/services/offline_user_data_job_service/transports/*',
                  'ads/googleads/v7/services/services/operating_system_version_constant_service/*',
                  'ads/googleads/v7/services/services/operating_system_version_constant_service/transports/*',
                  'ads/googleads/v7/services/services/paid_organic_search_term_view_service/*',
                  'ads/googleads/v7/services/services/paid_organic_search_term_view_service/transports/*',
                  'ads/googleads/v7/services/services/parental_status_view_service/*',
                  'ads/googleads/v7/services/services/parental_status_view_service/transports/*',
                  'ads/googleads/v7/services/services/payments_account_service/*',
                  'ads/googleads/v7/services/services/payments_account_service/transports/*',
                  'ads/googleads/v7/services/services/product_bidding_category_constant_service/*',
                  'ads/googleads/v7/services/services/product_bidding_category_constant_service/transports/*',
                  'ads/googleads/v7/services/services/product_group_view_service/*',
                  'ads/googleads/v7/services/services/product_group_view_service/transports/*',
                  'ads/googleads/v7/services/services/reach_plan_service/*',
                  'ads/googleads/v7/services/services/reach_plan_service/transports/*',
                  'ads/googleads/v7/services/services/recommendation_service/*',
                  'ads/googleads/v7/services/services/recommendation_service/transports/*',
                  'ads/googleads/v7/services/services/remarketing_action_service/*',
                  'ads/googleads/v7/services/services/remarketing_action_service/transports/*',
                  'ads/googleads/v7/services/services/search_term_view_service/*',
                  'ads/googleads/v7/services/services/search_term_view_service/transports/*',
                  'ads/googleads/v7/services/services/shared_criterion_service/*',
                  'ads/googleads/v7/services/services/shared_criterion_service/transports/*',
                  'ads/googleads/v7/services/services/shared_set_service/*',
                  'ads/googleads/v7/services/services/shared_set_service/transports/*',
                  'ads/googleads/v7/services/services/shopping_performance_view_service/*',
                  'ads/googleads/v7/services/services/shopping_performance_view_service/transports/*',
                  'ads/googleads/v7/services/services/third_party_app_analytics_link_service/*',
                  'ads/googleads/v7/services/services/third_party_app_analytics_link_service/transports/*',
                  'ads/googleads/v7/services/services/topic_constant_service/*',
                  'ads/googleads/v7/services/services/topic_constant_service/transports/*',
                  'ads/googleads/v7/services/services/topic_view_service/*',
                  'ads/googleads/v7/services/services/topic_view_service/transports/*',
                  'ads/googleads/v7/services/services/user_data_service/*',
                  'ads/googleads/v7/services/services/user_data_service/transports/*',
                  'ads/googleads/v7/services/services/user_interest_service/*',
                  'ads/googleads/v7/services/services/user_interest_service/transports/*',
                  'ads/googleads/v7/services/services/user_list_service/*',
                  'ads/googleads/v7/services/services/user_list_service/transports/*',
                  'ads/googleads/v7/services/services/user_location_view_service/*',
                  'ads/googleads/v7/services/services/user_location_view_service/transports/*',
                  'ads/googleads/v7/services/services/video_service/*',
                  'ads/googleads/v7/services/services/video_service/transports/*',
                  'ads/googleads/v7/services/services/webpage_view_service/*',
                  'ads/googleads/v7/services/services/webpage_view_service/transports/*',
                  'ads/googleads/v7/services/types/*',
                  'ads/googleads/v7/types/*',
                  'ads/googleads/v8/*',
                  'ads/googleads/v8/common/*',
                  'ads/googleads/v8/common/services/*',
                  'ads/googleads/v8/common/types/*',
                  'ads/googleads/v8/enums/*',
                  'ads/googleads/v8/enums/services/*',
                  'ads/googleads/v8/enums/types/*',
                  'ads/googleads/v8/errors/*',
                  'ads/googleads/v8/errors/services/*',
                  'ads/googleads/v8/errors/types/*',
                  'ads/googleads/v8/resources/*',
                  'ads/googleads/v8/resources/services/*',
                  'ads/googleads/v8/resources/types/*',
                  'ads/googleads/v8/services/*',
                  'ads/googleads/v8/services/services/*',
                  'ads/googleads/v8/services/services/accessible_bidding_strategy_service/*',
                  'ads/googleads/v8/services/services/accessible_bidding_strategy_service/transports/*',
                  'ads/googleads/v8/services/services/account_budget_proposal_service/*',
                  'ads/googleads/v8/services/services/account_budget_proposal_service/transports/*',
                  'ads/googleads/v8/services/services/account_budget_service/*',
                  'ads/googleads/v8/services/services/account_budget_service/transports/*',
                  'ads/googleads/v8/services/services/account_link_service/*',
                  'ads/googleads/v8/services/services/account_link_service/transports/*',
                  'ads/googleads/v8/services/services/ad_group_ad_asset_view_service/*',
                  'ads/googleads/v8/services/services/ad_group_ad_asset_view_service/transports/*',
                  'ads/googleads/v8/services/services/ad_group_ad_label_service/*',
                  'ads/googleads/v8/services/services/ad_group_ad_label_service/transports/*',
                  'ads/googleads/v8/services/services/ad_group_ad_service/*',
                  'ads/googleads/v8/services/services/ad_group_ad_service/transports/*',
                  'ads/googleads/v8/services/services/ad_group_asset_service/*',
                  'ads/googleads/v8/services/services/ad_group_asset_service/transports/*',
                  'ads/googleads/v8/services/services/ad_group_audience_view_service/*',
                  'ads/googleads/v8/services/services/ad_group_audience_view_service/transports/*',
                  'ads/googleads/v8/services/services/ad_group_bid_modifier_service/*',
                  'ads/googleads/v8/services/services/ad_group_bid_modifier_service/transports/*',
                  'ads/googleads/v8/services/services/ad_group_criterion_label_service/*',
                  'ads/googleads/v8/services/services/ad_group_criterion_label_service/transports/*',
                  'ads/googleads/v8/services/services/ad_group_criterion_service/*',
                  'ads/googleads/v8/services/services/ad_group_criterion_service/transports/*',
                  'ads/googleads/v8/services/services/ad_group_criterion_simulation_service/*',
                  'ads/googleads/v8/services/services/ad_group_criterion_simulation_service/transports/*',
                  'ads/googleads/v8/services/services/ad_group_extension_setting_service/*',
                  'ads/googleads/v8/services/services/ad_group_extension_setting_service/transports/*',
                  'ads/googleads/v8/services/services/ad_group_feed_service/*',
                  'ads/googleads/v8/services/services/ad_group_feed_service/transports/*',
                  'ads/googleads/v8/services/services/ad_group_label_service/*',
                  'ads/googleads/v8/services/services/ad_group_label_service/transports/*',
                  'ads/googleads/v8/services/services/ad_group_service/*',
                  'ads/googleads/v8/services/services/ad_group_service/transports/*',
                  'ads/googleads/v8/services/services/ad_group_simulation_service/*',
                  'ads/googleads/v8/services/services/ad_group_simulation_service/transports/*',
                  'ads/googleads/v8/services/services/ad_parameter_service/*',
                  'ads/googleads/v8/services/services/ad_parameter_service/transports/*',
                  'ads/googleads/v8/services/services/ad_schedule_view_service/*',
                  'ads/googleads/v8/services/services/ad_schedule_view_service/transports/*',
                  'ads/googleads/v8/services/services/ad_service/*',
                  'ads/googleads/v8/services/services/ad_service/transports/*',
                  'ads/googleads/v8/services/services/age_range_view_service/*',
                  'ads/googleads/v8/services/services/age_range_view_service/transports/*',
                  'ads/googleads/v8/services/services/asset_field_type_view_service/*',
                  'ads/googleads/v8/services/services/asset_field_type_view_service/transports/*',
                  'ads/googleads/v8/services/services/asset_service/*',
                  'ads/googleads/v8/services/services/asset_service/transports/*',
                  'ads/googleads/v8/services/services/batch_job_service/*',
                  'ads/googleads/v8/services/services/batch_job_service/transports/*',
                  'ads/googleads/v8/services/services/bidding_data_exclusion_service/*',
                  'ads/googleads/v8/services/services/bidding_data_exclusion_service/transports/*',
                  'ads/googleads/v8/services/services/bidding_seasonality_adjustment_service/*',
                  'ads/googleads/v8/services/services/bidding_seasonality_adjustment_service/transports/*',
                  'ads/googleads/v8/services/services/bidding_strategy_service/*',
                  'ads/googleads/v8/services/services/bidding_strategy_service/transports/*',
                  'ads/googleads/v8/services/services/bidding_strategy_simulation_service/*',
                  'ads/googleads/v8/services/services/bidding_strategy_simulation_service/transports/*',
                  'ads/googleads/v8/services/services/billing_setup_service/*',
                  'ads/googleads/v8/services/services/billing_setup_service/transports/*',
                  'ads/googleads/v8/services/services/campaign_asset_service/*',
                  'ads/googleads/v8/services/services/campaign_asset_service/transports/*',
                  'ads/googleads/v8/services/services/campaign_audience_view_service/*',
                  'ads/googleads/v8/services/services/campaign_audience_view_service/transports/*',
                  'ads/googleads/v8/services/services/campaign_bid_modifier_service/*',
                  'ads/googleads/v8/services/services/campaign_bid_modifier_service/transports/*',
                  'ads/googleads/v8/services/services/campaign_budget_service/*',
                  'ads/googleads/v8/services/services/campaign_budget_service/transports/*',
                  'ads/googleads/v8/services/services/campaign_criterion_service/*',
                  'ads/googleads/v8/services/services/campaign_criterion_service/transports/*',
                  'ads/googleads/v8/services/services/campaign_criterion_simulation_service/*',
                  'ads/googleads/v8/services/services/campaign_criterion_simulation_service/transports/*',
                  'ads/googleads/v8/services/services/campaign_draft_service/*',
                  'ads/googleads/v8/services/services/campaign_draft_service/transports/*',
                  'ads/googleads/v8/services/services/campaign_experiment_service/*',
                  'ads/googleads/v8/services/services/campaign_experiment_service/transports/*',
                  'ads/googleads/v8/services/services/campaign_extension_setting_service/*',
                  'ads/googleads/v8/services/services/campaign_extension_setting_service/transports/*',
                  'ads/googleads/v8/services/services/campaign_feed_service/*',
                  'ads/googleads/v8/services/services/campaign_feed_service/transports/*',
                  'ads/googleads/v8/services/services/campaign_label_service/*',
                  'ads/googleads/v8/services/services/campaign_label_service/transports/*',
                  'ads/googleads/v8/services/services/campaign_service/*',
                  'ads/googleads/v8/services/services/campaign_service/transports/*',
                  'ads/googleads/v8/services/services/campaign_shared_set_service/*',
                  'ads/googleads/v8/services/services/campaign_shared_set_service/transports/*',
                  'ads/googleads/v8/services/services/campaign_simulation_service/*',
                  'ads/googleads/v8/services/services/campaign_simulation_service/transports/*',
                  'ads/googleads/v8/services/services/carrier_constant_service/*',
                  'ads/googleads/v8/services/services/carrier_constant_service/transports/*',
                  'ads/googleads/v8/services/services/change_status_service/*',
                  'ads/googleads/v8/services/services/change_status_service/transports/*',
                  'ads/googleads/v8/services/services/click_view_service/*',
                  'ads/googleads/v8/services/services/click_view_service/transports/*',
                  'ads/googleads/v8/services/services/combined_audience_service/*',
                  'ads/googleads/v8/services/services/combined_audience_service/transports/*',
                  'ads/googleads/v8/services/services/conversion_action_service/*',
                  'ads/googleads/v8/services/services/conversion_action_service/transports/*',
                  'ads/googleads/v8/services/services/conversion_adjustment_upload_service/*',
                  'ads/googleads/v8/services/services/conversion_adjustment_upload_service/transports/*',
                  'ads/googleads/v8/services/services/conversion_custom_variable_service/*',
                  'ads/googleads/v8/services/services/conversion_custom_variable_service/transports/*',
                  'ads/googleads/v8/services/services/conversion_upload_service/*',
                  'ads/googleads/v8/services/services/conversion_upload_service/transports/*',
                  'ads/googleads/v8/services/services/conversion_value_rule_service/*',
                  'ads/googleads/v8/services/services/conversion_value_rule_service/transports/*',
                  'ads/googleads/v8/services/services/conversion_value_rule_set_service/*',
                  'ads/googleads/v8/services/services/conversion_value_rule_set_service/transports/*',
                  'ads/googleads/v8/services/services/currency_constant_service/*',
                  'ads/googleads/v8/services/services/currency_constant_service/transports/*',
                  'ads/googleads/v8/services/services/custom_audience_service/*',
                  'ads/googleads/v8/services/services/custom_audience_service/transports/*',
                  'ads/googleads/v8/services/services/custom_interest_service/*',
                  'ads/googleads/v8/services/services/custom_interest_service/transports/*',
                  'ads/googleads/v8/services/services/customer_asset_service/*',
                  'ads/googleads/v8/services/services/customer_asset_service/transports/*',
                  'ads/googleads/v8/services/services/customer_client_link_service/*',
                  'ads/googleads/v8/services/services/customer_client_link_service/transports/*',
                  'ads/googleads/v8/services/services/customer_client_service/*',
                  'ads/googleads/v8/services/services/customer_client_service/transports/*',
                  'ads/googleads/v8/services/services/customer_extension_setting_service/*',
                  'ads/googleads/v8/services/services/customer_extension_setting_service/transports/*',
                  'ads/googleads/v8/services/services/customer_feed_service/*',
                  'ads/googleads/v8/services/services/customer_feed_service/transports/*',
                  'ads/googleads/v8/services/services/customer_label_service/*',
                  'ads/googleads/v8/services/services/customer_label_service/transports/*',
                  'ads/googleads/v8/services/services/customer_manager_link_service/*',
                  'ads/googleads/v8/services/services/customer_manager_link_service/transports/*',
                  'ads/googleads/v8/services/services/customer_negative_criterion_service/*',
                  'ads/googleads/v8/services/services/customer_negative_criterion_service/transports/*',
                  'ads/googleads/v8/services/services/customer_service/*',
                  'ads/googleads/v8/services/services/customer_service/transports/*',
                  'ads/googleads/v8/services/services/customer_user_access_invitation_service/*',
                  'ads/googleads/v8/services/services/customer_user_access_invitation_service/transports/*',
                  'ads/googleads/v8/services/services/customer_user_access_service/*',
                  'ads/googleads/v8/services/services/customer_user_access_service/transports/*',
                  'ads/googleads/v8/services/services/detail_placement_view_service/*',
                  'ads/googleads/v8/services/services/detail_placement_view_service/transports/*',
                  'ads/googleads/v8/services/services/detailed_demographic_service/*',
                  'ads/googleads/v8/services/services/detailed_demographic_service/transports/*',
                  'ads/googleads/v8/services/services/display_keyword_view_service/*',
                  'ads/googleads/v8/services/services/display_keyword_view_service/transports/*',
                  'ads/googleads/v8/services/services/distance_view_service/*',
                  'ads/googleads/v8/services/services/distance_view_service/transports/*',
                  'ads/googleads/v8/services/services/domain_category_service/*',
                  'ads/googleads/v8/services/services/domain_category_service/transports/*',
                  'ads/googleads/v8/services/services/dynamic_search_ads_search_term_view_service/*',
                  'ads/googleads/v8/services/services/dynamic_search_ads_search_term_view_service/transports/*',
                  'ads/googleads/v8/services/services/expanded_landing_page_view_service/*',
                  'ads/googleads/v8/services/services/expanded_landing_page_view_service/transports/*',
                  'ads/googleads/v8/services/services/extension_feed_item_service/*',
                  'ads/googleads/v8/services/services/extension_feed_item_service/transports/*',
                  'ads/googleads/v8/services/services/feed_item_service/*',
                  'ads/googleads/v8/services/services/feed_item_service/transports/*',
                  'ads/googleads/v8/services/services/feed_item_set_link_service/*',
                  'ads/googleads/v8/services/services/feed_item_set_link_service/transports/*',
                  'ads/googleads/v8/services/services/feed_item_set_service/*',
                  'ads/googleads/v8/services/services/feed_item_set_service/transports/*',
                  'ads/googleads/v8/services/services/feed_item_target_service/*',
                  'ads/googleads/v8/services/services/feed_item_target_service/transports/*',
                  'ads/googleads/v8/services/services/feed_mapping_service/*',
                  'ads/googleads/v8/services/services/feed_mapping_service/transports/*',
                  'ads/googleads/v8/services/services/feed_placeholder_view_service/*',
                  'ads/googleads/v8/services/services/feed_placeholder_view_service/transports/*',
                  'ads/googleads/v8/services/services/feed_service/*',
                  'ads/googleads/v8/services/services/feed_service/transports/*',
                  'ads/googleads/v8/services/services/gender_view_service/*',
                  'ads/googleads/v8/services/services/gender_view_service/transports/*',
                  'ads/googleads/v8/services/services/geo_target_constant_service/*',
                  'ads/googleads/v8/services/services/geo_target_constant_service/transports/*',
                  'ads/googleads/v8/services/services/geographic_view_service/*',
                  'ads/googleads/v8/services/services/geographic_view_service/transports/*',
                  'ads/googleads/v8/services/services/google_ads_field_service/*',
                  'ads/googleads/v8/services/services/google_ads_field_service/transports/*',
                  'ads/googleads/v8/services/services/google_ads_service/*',
                  'ads/googleads/v8/services/services/google_ads_service/transports/*',
                  'ads/googleads/v8/services/services/group_placement_view_service/*',
                  'ads/googleads/v8/services/services/group_placement_view_service/transports/*',
                  'ads/googleads/v8/services/services/hotel_group_view_service/*',
                  'ads/googleads/v8/services/services/hotel_group_view_service/transports/*',
                  'ads/googleads/v8/services/services/hotel_performance_view_service/*',
                  'ads/googleads/v8/services/services/hotel_performance_view_service/transports/*',
                  'ads/googleads/v8/services/services/income_range_view_service/*',
                  'ads/googleads/v8/services/services/income_range_view_service/transports/*',
                  'ads/googleads/v8/services/services/invoice_service/*',
                  'ads/googleads/v8/services/services/invoice_service/transports/*',
                  'ads/googleads/v8/services/services/keyword_plan_ad_group_keyword_service/*',
                  'ads/googleads/v8/services/services/keyword_plan_ad_group_keyword_service/transports/*',
                  'ads/googleads/v8/services/services/keyword_plan_ad_group_service/*',
                  'ads/googleads/v8/services/services/keyword_plan_ad_group_service/transports/*',
                  'ads/googleads/v8/services/services/keyword_plan_campaign_keyword_service/*',
                  'ads/googleads/v8/services/services/keyword_plan_campaign_keyword_service/transports/*',
                  'ads/googleads/v8/services/services/keyword_plan_campaign_service/*',
                  'ads/googleads/v8/services/services/keyword_plan_campaign_service/transports/*',
                  'ads/googleads/v8/services/services/keyword_plan_idea_service/*',
                  'ads/googleads/v8/services/services/keyword_plan_idea_service/transports/*',
                  'ads/googleads/v8/services/services/keyword_plan_service/*',
                  'ads/googleads/v8/services/services/keyword_plan_service/transports/*',
                  'ads/googleads/v8/services/services/keyword_theme_constant_service/*',
                  'ads/googleads/v8/services/services/keyword_theme_constant_service/transports/*',
                  'ads/googleads/v8/services/services/keyword_view_service/*',
                  'ads/googleads/v8/services/services/keyword_view_service/transports/*',
                  'ads/googleads/v8/services/services/label_service/*',
                  'ads/googleads/v8/services/services/label_service/transports/*',
                  'ads/googleads/v8/services/services/landing_page_view_service/*',
                  'ads/googleads/v8/services/services/landing_page_view_service/transports/*',
                  'ads/googleads/v8/services/services/language_constant_service/*',
                  'ads/googleads/v8/services/services/language_constant_service/transports/*',
                  'ads/googleads/v8/services/services/life_event_service/*',
                  'ads/googleads/v8/services/services/life_event_service/transports/*',
                  'ads/googleads/v8/services/services/location_view_service/*',
                  'ads/googleads/v8/services/services/location_view_service/transports/*',
                  'ads/googleads/v8/services/services/managed_placement_view_service/*',
                  'ads/googleads/v8/services/services/managed_placement_view_service/transports/*',
                  'ads/googleads/v8/services/services/media_file_service/*',
                  'ads/googleads/v8/services/services/media_file_service/transports/*',
                  'ads/googleads/v8/services/services/merchant_center_link_service/*',
                  'ads/googleads/v8/services/services/merchant_center_link_service/transports/*',
                  'ads/googleads/v8/services/services/mobile_app_category_constant_service/*',
                  'ads/googleads/v8/services/services/mobile_app_category_constant_service/transports/*',
                  'ads/googleads/v8/services/services/mobile_device_constant_service/*',
                  'ads/googleads/v8/services/services/mobile_device_constant_service/transports/*',
                  'ads/googleads/v8/services/services/offline_user_data_job_service/*',
                  'ads/googleads/v8/services/services/offline_user_data_job_service/transports/*',
                  'ads/googleads/v8/services/services/operating_system_version_constant_service/*',
                  'ads/googleads/v8/services/services/operating_system_version_constant_service/transports/*',
                  'ads/googleads/v8/services/services/paid_organic_search_term_view_service/*',
                  'ads/googleads/v8/services/services/paid_organic_search_term_view_service/transports/*',
                  'ads/googleads/v8/services/services/parental_status_view_service/*',
                  'ads/googleads/v8/services/services/parental_status_view_service/transports/*',
                  'ads/googleads/v8/services/services/payments_account_service/*',
                  'ads/googleads/v8/services/services/payments_account_service/transports/*',
                  'ads/googleads/v8/services/services/product_bidding_category_constant_service/*',
                  'ads/googleads/v8/services/services/product_bidding_category_constant_service/transports/*',
                  'ads/googleads/v8/services/services/product_group_view_service/*',
                  'ads/googleads/v8/services/services/product_group_view_service/transports/*',
                  'ads/googleads/v8/services/services/reach_plan_service/*',
                  'ads/googleads/v8/services/services/reach_plan_service/transports/*',
                  'ads/googleads/v8/services/services/recommendation_service/*',
                  'ads/googleads/v8/services/services/recommendation_service/transports/*',
                  'ads/googleads/v8/services/services/remarketing_action_service/*',
                  'ads/googleads/v8/services/services/remarketing_action_service/transports/*',
                  'ads/googleads/v8/services/services/search_term_view_service/*',
                  'ads/googleads/v8/services/services/search_term_view_service/transports/*',
                  'ads/googleads/v8/services/services/shared_criterion_service/*',
                  'ads/googleads/v8/services/services/shared_criterion_service/transports/*',
                  'ads/googleads/v8/services/services/shared_set_service/*',
                  'ads/googleads/v8/services/services/shared_set_service/transports/*',
                  'ads/googleads/v8/services/services/shopping_performance_view_service/*',
                  'ads/googleads/v8/services/services/shopping_performance_view_service/transports/*',
                  'ads/googleads/v8/services/services/smart_campaign_search_term_view_service/*',
                  'ads/googleads/v8/services/services/smart_campaign_search_term_view_service/transports/*',
                  'ads/googleads/v8/services/services/smart_campaign_setting_service/*',
                  'ads/googleads/v8/services/services/smart_campaign_setting_service/transports/*',
                  'ads/googleads/v8/services/services/smart_campaign_suggest_service/*',
                  'ads/googleads/v8/services/services/smart_campaign_suggest_service/transports/*',
                  'ads/googleads/v8/services/services/third_party_app_analytics_link_service/*',
                  'ads/googleads/v8/services/services/third_party_app_analytics_link_service/transports/*',
                  'ads/googleads/v8/services/services/topic_constant_service/*',
                  'ads/googleads/v8/services/services/topic_constant_service/transports/*',
                  'ads/googleads/v8/services/services/topic_view_service/*',
                  'ads/googleads/v8/services/services/topic_view_service/transports/*',
                  'ads/googleads/v8/services/services/user_data_service/*',
                  'ads/googleads/v8/services/services/user_data_service/transports/*',
                  'ads/googleads/v8/services/services/user_interest_service/*',
                  'ads/googleads/v8/services/services/user_interest_service/transports/*',
                  'ads/googleads/v8/services/services/user_list_service/*',
                  'ads/googleads/v8/services/services/user_list_service/transports/*',
                  'ads/googleads/v8/services/services/user_location_view_service/*',
                  'ads/googleads/v8/services/services/user_location_view_service/transports/*',
                  'ads/googleads/v8/services/services/video_service/*',
                  'ads/googleads/v8/services/services/video_service/transports/*',
                  'ads/googleads/v8/services/services/webpage_view_service/*',
                  'ads/googleads/v8/services/services/webpage_view_service/transports/*',
                  'ads/googleads/v8/services/types/*',
                  'ads/googleads/v8/types/*']}

install_requires = \
['google-ads>=14.0.0,<15.0.0',
 'google-auth-stubs>=0.1.0,<0.2.0',
 'googleapis-common-protos-stubs>=2.0.0,<3.0.0',
 'grpc-stubs>=1.24.7,<2.0.0',
 'proto-plus-stubs>=0.1.0,<0.2.0',
 'types-protobuf>=3.18.0,<4.0.0',
 'typing-extensions>=3.10.0,<4.0.0']

setup_kwargs = {
    'name': 'google-ads-stubs',
    'version': '8.0.0',
    'description': 'Type stubs for google-ads',
    'long_description': "# Type stubs for the Google Ads API Client Library for Python\n\n[![PyPI version](https://badge.fury.io/py/google-ads-stubs.svg)](https://badge.fury.io/py/google-ads-stubs)\n\nThis package provides type stubs for the [Google Ads API Client Library for Python](https://github.com/googleads/google-ads-python). \nIt's currently compatible with v14.0.0 of this library. It allows you to type check usage of the library with e.g. [mypy](http://mypy-lang.org/) and will also improve autocomplete in many editors.\n\n**This is in no way affiliated with Google.**\n\nMost stubs were created automatically by [stubgen](https://mypy.readthedocs.io/en/stable/stubgen.html), the rest are handwritten or generated by self-made scripts.\n\nIf you find incorrect annotations, please create an issue. Contributions for fixes are also welcome.\n\n## Installation\n\n```\n$ pip install google-ads-stubs\n```\n\n## Caveats\n\nThere are some caveats. The primary one is that type inference does _not_ work for the `get_type` and `get_service`\nmethods of `Client`. The workaround is to explicitly state the type. For `get_type` you can also instantiate\nthe object directly.\n\n```python\n# Replace this:\ncampaign_operation = client.get_type('CampaignOperation')\n# With this:\nfrom google.ads.googleads.v8 import CampaignOperation\ncampaign_operation: CampaignOperation = client.get_type('CampaignOperation')\n# Or this:\nfrom google.ads.googleads.v8 import CampaignOperation\ncampaign_operation = CampaignOperation()\n\n# Replace this:\ngoogle_ads_service = client.get_service('GoogleAdsService')\n# With this:\nfrom google.ads.googleads.v8 import GoogleAdsServiceClient\ngoogle_ads_service: GoogleAdsServiceClient = client.get_service('GoogleAdsService')\n```\n\nWhile it is technically possible to type these methods using a combination of overloading and literal types,\nthis is not included in these stubs. The reason is that it requires about 10,000 overloads, which makes most typecheckers fairly slow.\n\nAnother big caveat since v8.0.0 of this package is that the attributes and constructor arguments of the protobuf messages are all typed as `Any` instead of their proper types. This is due to `google-ads-python` switching from raw protobuf message classes to `proto-plus` classes. Better types for these might be introduced in the future. `GoogleAdsClient.enums` is also typed as `Any`.\n\n\nNote that if you're using Mypy you need to use the `--namespace-packages` option as `google` and `google.ads` are namespace packages.",
    'author': 'Henrik Bruåsdal',
    'author_email': 'henrik.bruasdal@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/henribru/google-ads-stubs',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
