from typing import Any

import proto

__protobuf__: Any

class ListingGroupTypeEnum(proto.Message):
    class ListingGroupType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        SUBDIVISION: int
        UNIT: int
