from typing import Any

import proto

__protobuf__: Any

class OfflineUserDataJobErrorEnum(proto.Message):
    class OfflineUserDataJobError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        INVALID_USER_LIST_ID: int
        INVALID_USER_LIST_TYPE: int
        NOT_ON_ALLOWLIST_FOR_USER_ID: int
        INCOMPATIBLE_UPLOAD_KEY_TYPE: int
        MISSING_USER_IDENTIFIER: int
        INVALID_MOBILE_ID_FORMAT: int
        TOO_MANY_USER_IDENTIFIERS: int
        NOT_ON_ALLOWLIST_FOR_STORE_SALES_DIRECT: int
        NOT_ON_ALLOWLIST_FOR_UNIFIED_STORE_SALES: int
        INVALID_PARTNER_ID: int
        INVALID_ENCODING: int
        INVALID_COUNTRY_CODE: int
        INCOMPATIBLE_USER_IDENTIFIER: int
        FUTURE_TRANSACTION_TIME: int
        INVALID_CONVERSION_ACTION: int
        MOBILE_ID_NOT_SUPPORTED: int
        INVALID_OPERATION_ORDER: int
        CONFLICTING_OPERATION: int
        EXTERNAL_UPDATE_ID_ALREADY_EXISTS: int
        JOB_ALREADY_STARTED: int
        REMOVE_NOT_SUPPORTED: int
        REMOVE_ALL_NOT_SUPPORTED: int
        INVALID_SHA256_FORMAT: int
        CUSTOM_KEY_DISABLED: int
        CUSTOM_KEY_NOT_PREDEFINED: int
        CUSTOM_KEY_NOT_SET: int
        CUSTOMER_NOT_ACCEPTED_CUSTOMER_DATA_TERMS: int
        ATTRIBUTES_NOT_APPLICABLE_FOR_CUSTOMER_MATCH_USER_LIST: int
        LIFETIME_VALUE_BUCKET_NOT_IN_RANGE: int
        INCOMPATIBLE_USER_IDENTIFIER_FOR_ATTRIBUTES: int
