from typing import Any

import proto

__protobuf__: Any

class DetailPlacementView(proto.Message):
    resource_name: Any
    placement: Any
    display_name: Any
    group_placement_target_url: Any
    target_url: Any
    placement_type: Any
