from typing import Any

import proto

__protobuf__: Any

class GoogleAdsFieldCategoryEnum(proto.Message):
    class GoogleAdsFieldCategory(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        RESOURCE: int
        ATTRIBUTE: int
        SEGMENT: int
        METRIC: int
