from typing import Any

import proto

__protobuf__: Any

class AppPaymentModelTypeEnum(proto.Message):
    class AppPaymentModelType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        PAID: int
