from typing import Any

import proto

from google.ads.googleads.v8.enums.types import (
    combined_audience_status as combined_audience_status,
)

__protobuf__: Any

class CombinedAudience(proto.Message):
    resource_name: Any
    id: Any
    status: Any
    name: Any
    description: Any
