from typing import Any

import proto

__protobuf__: Any

class KeywordPlanIdeaErrorEnum(proto.Message):
    class KeywordPlanIdeaError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        URL_CRAWL_ERROR: int
        INVALID_VALUE: int
