from typing import Any

import proto

__protobuf__: Any

class MultiplierErrorEnum(proto.Message):
    class MultiplierError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        MULTIPLIER_TOO_HIGH: int
        MULTIPLIER_TOO_LOW: int
        TOO_MANY_FRACTIONAL_DIGITS: int
        MULTIPLIER_NOT_ALLOWED_FOR_BIDDING_STRATEGY: int
        MULTIPLIER_NOT_ALLOWED_WHEN_BASE_BID_IS_MISSING: int
        NO_MULTIPLIER_SPECIFIED: int
        MULTIPLIER_CAUSES_BID_TO_EXCEED_DAILY_BUDGET: int
        MULTIPLIER_CAUSES_BID_TO_EXCEED_MONTHLY_BUDGET: int
        MULTIPLIER_CAUSES_BID_TO_EXCEED_CUSTOM_BUDGET: int
        MULTIPLIER_CAUSES_BID_TO_EXCEED_MAX_ALLOWED_BID: int
        BID_LESS_THAN_MIN_ALLOWED_BID_WITH_MULTIPLIER: int
        MULTIPLIER_AND_BIDDING_STRATEGY_TYPE_MISMATCH: int
