from typing import Any

import proto

__protobuf__: Any

class GroupPlacementView(proto.Message):
    resource_name: Any
    placement: Any
    display_name: Any
    target_url: Any
    placement_type: Any
