from typing import Any

import proto

__protobuf__: Any

class ConversionUploadErrorEnum(proto.Message):
    class ConversionUploadError(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        TOO_MANY_CONVERSIONS_IN_REQUEST: int
        UNPARSEABLE_GCLID: int
        CONVERSION_PRECEDES_GCLID: int
        EXPIRED_GCLID: int
        TOO_RECENT_GCLID: int
        GCLID_NOT_FOUND: int
        UNAUTHORIZED_CUSTOMER: int
        INVALID_CONVERSION_ACTION: int
        TOO_RECENT_CONVERSION_ACTION: int
        CONVERSION_TRACKING_NOT_ENABLED_AT_IMPRESSION_TIME: int
        EXTERNAL_ATTRIBUTION_DATA_SET_FOR_NON_EXTERNALLY_ATTRIBUTED_CONVERSION_ACTION: int
        EXTERNAL_ATTRIBUTION_DATA_NOT_SET_FOR_EXTERNALLY_ATTRIBUTED_CONVERSION_ACTION: int
        ORDER_ID_NOT_PERMITTED_FOR_EXTERNALLY_ATTRIBUTED_CONVERSION_ACTION: int
        ORDER_ID_ALREADY_IN_USE: int
        DUPLICATE_ORDER_ID: int
        TOO_RECENT_CALL: int
        EXPIRED_CALL: int
        CALL_NOT_FOUND: int
        CONVERSION_PRECEDES_CALL: int
        CONVERSION_TRACKING_NOT_ENABLED_AT_CALL_TIME: int
        UNPARSEABLE_CALLERS_PHONE_NUMBER: int
        CUSTOM_VARIABLE_NOT_ENABLED: int
        CUSTOM_VARIABLE_VALUE_CONTAINS_PII: int
        INVALID_CUSTOMER_FOR_CLICK: int
        INVALID_CUSTOMER_FOR_CALL: int
        CONVERSION_NOT_COMPLIANT_WITH_ATT_POLICY: int
        CLICK_NOT_FOUND: int
        INVALID_USER_IDENTIFIER: int
        EXTERNALLY_ATTRIBUTED_CONVERSION_ACTION_NOT_PERMITTED_WITH_USER_IDENTIFIER: int
        UNSUPPORTED_USER_IDENTIFIER: int
        INVALID_USER_IDENTIFIER_SOURCE: int
