from typing import Any

import proto

from google.ads.googleads.v7.common.types import (
    click_location as click_location,
    criteria as criteria,
)

__protobuf__: Any

class ClickView(proto.Message):
    resource_name: Any
    gclid: Any
    area_of_interest: Any
    location_of_presence: Any
    page_number: Any
    ad_group_ad: Any
    campaign_location_target: Any
    user_list: Any
    keyword: Any
    keyword_info: Any
