from typing import Any

import proto

__protobuf__: Any

class ValueRuleSetAttachmentTypeEnum(proto.Message):
    class ValueRuleSetAttachmentType(proto.Enum):
        UNSPECIFIED: int
        UNKNOWN: int
        CUSTOMER: int
        CAMPAIGN: int
